@@ -35,6 +35,8 @@ module fft_saveval_define
   integer, save :: restp   ! restart output interval
   integer, save :: resopt  ! restart option
   integer, save :: force_type  ! Type of the stretching forcing
+  integer, save :: force_wn  ! Azimuthal wavenumber for stretching forcing
+  integer, save :: force_kr(2)  ! Radial range of stretching forcing in grid number
 
   double precision, save :: Lx      ! calculating domain of x direction
   double precision, save :: Ly      ! calculating domain of y direction
@@ -71,6 +73,8 @@ module fft_saveval_define
   double precision, save :: dx      ! grid interval of x direction
   double precision, save :: dy      ! grid interval of y direction
   double precision, save :: f0      ! Coriolis parameter
+  double precision, save :: tcx     ! Vortex center of x direction
+  double precision, save :: tcy     ! Vortex center of y direction
   real, save :: restime             ! restart starting time
   double precision, allocatable, dimension(:), save :: xi ! array of x direction
   double precision, allocatable, dimension(:), save :: yi ! array of y direction
@@ -120,4 +124,8 @@ module fft_saveval_define
   double precision, allocatable, dimension(:), save :: TJJ
   double precision, allocatable, dimension(:), save :: TIJ
 
+!-- monitoring variables
+  complex(kind(0d0)), allocatable, dimension(:,:), save :: dmp_stretchk
+  complex(kind(0d0)), allocatable, dimension(:,:), save :: dmp_advectk
+
 end module fft_saveval_define
