@@ -1,6 +1,7 @@
 module fftsub_mod
 
   use ffts
+  use typhoon_analy
 
 contains
 
@@ -292,6 +293,129 @@ subroutine psik2zetak( psik, zk, zkopt )
 end subroutine psik2zetak
 
 
+subroutine azimuth_filter( ioval )
+!-- Filter a specified azimuthal wavenumber (force_wn) in ioval and return ioval
+  use Math_Const
+  use fft_saveval_define
+  implicit none
+  double precision, intent(inout) :: ioval(:,:)
+  double precision, allocatable, dimension(:) :: rad, theta
+  double precision, allocatable, dimension(:,:) :: ioval_rt
+  complex(kind(0d0)), allocatable, dimension(:,:) :: cpval_rt, sp_rt, spout_rt
+  double precision :: dxtmp, dytmp
+  integer :: ii, jj, ix, jy, kk, kr
+  integer :: ixc, jyc, ixmin, ixmax, jymin, jymax
+!-- OpenMP variables
+!$ integer :: OMP_GET_THREAD_NUM, OMP_GET_MAX_THREADS
+  integer :: ompnum, omppe
+
+  ix=size(ioval,1)  ! =jxnt
+  jy=size(ioval,2)  ! =jynt
+  dxtmp=dx*dble(nx-1)/dble(jxnt-1)
+  dytmp=dy*dble(ny-1)/dble(jynt-1)
+
+!-- internal variables for OpenMP
+  ompnum=1
+  omppe=1
+!$   ompnum=OMP_GET_MAX_THREADS()  ! Activated in using OpenMP
+
+  !-- search the minimum grid number in radius
+  !kr=nint(min(min(tcx-xj(1),xj(jxnt)-tcx)/dxtmp,min(tcy-yj(1),yj(jynt)-tcy)/dytmp))
+  kr=force_kr(2)
+  allocate(rad(kr))
+  allocate(theta(jy))
+  allocate(ioval_rt(kr,jy))
+  allocate(cpval_rt(kr,jy))
+
+  rad(1:kr)=(/((dxtmp*dble(ii)),ii=1,kr)/)
+  theta(1:jy)=(/((2.0d0*pi_dp*dble(jj-1)/dble(jy)),jj=1,jy)/)
+  ioval_rt=0.0d0
+  cpval_rt=0.0d0
+
+  allocate(sp_rt(jy,ompnum))
+  allocate(spout_rt(jy,ompnum))
+
+  call interpo_search_1d( xj, tcx, ixc, stdopt=.true. )
+  call interpo_search_1d( yj, tcy, jyc, stdopt=.true. )
+  ixmin=ixc-kr-1
+  ixmax=ixc+kr+1
+  jymin=jyc-kr-1
+  jymax=jyc+kr+1
+  if(ixmin<1)then
+     ixmin=1
+  end if
+  if(ixmax>jxnt)then
+     ixmax=jxnt
+  end if
+  if(jymin<1)then
+     jymin=1
+  end if
+  if(jymax>jynt)then
+     jymax=jynt
+  end if
+
+  !-- 1. convert ioval from X-Y to R-T
+  call tangent_conv_scal( xj(ixmin:ixmax), yj(jymin:jymax), tcx, tcy,  &
+  &                       ioval(ixmin:ixmax,jymin:jymax),  &
+  &                       rad, theta, ioval_rt(1:kr,1:jy), undef=0.0d0,  &
+  &                       undefg=0.0d0, undefgc='inc',  &
+  &                       axis='xy', stdopt=.true. )
+
+  do jj=1,jy
+     do kk=force_kr(1),force_kr(2)
+        cpval_rt(kk,jj)=ioval_rt(kk,jj)
+     end do
+  end do
+  ioval=0.0d0
+  ioval_rt=0.0d0
+  sp_rt=0.0d0
+  spout_rt=0.0d0
+
+  !-- 2. filter force_wn
+!$omp parallel default(shared)
+!$omp do schedule(runtime) private(kk,omppe)
+  do kk=force_kr(1),force_kr(2)
+     !-- For OpenMP
+!$   omppe=OMP_GET_THREAD_NUM()+1  ! Activated in using OpenMP
+
+     !-- r_FFT
+     call ffttp_1d( jy, cpval_rt(kk,1:jy), sp_rt(1:jy,omppe), csign='r',  &
+  &                 prim='o', prim_fact=pyfact,  &
+  &                 omega_fix=omegayjbr, omegan_fix=omegayjnr )
+     !-- Filtering
+     spout_rt(force_wn+1,omppe)=sp_rt(force_wn+1,omppe)
+     spout_rt(jy-(force_wn-1),omppe)=sp_rt(jy-(force_wn-1),omppe)
+     !-- i_FFT
+     call ffttp_1d( jy, spout_rt(1:jy,omppe), cpval_rt(kk,1:jy), csign='i',  &
+  &                 prim='o', prim_fact=pyfact,  &
+  &                 omega_fix=omegayjbi, omegan_fix=omegayjni )
+  end do
+!$omp end do
+!$omp end parallel
+
+  do jj=1,jy
+     do kk=force_kr(1),force_kr(2)
+        ioval_rt(kk,jj)=dble(cpval_rt(kk,jj))
+     end do
+  end do
+
+  !-- 3. convert ioval (filterred) from R-T to X-Y
+  call Cart_conv_scal( rad, theta, ioval_rt(1:kr,1:jy),  &
+  &                    xj(ixmin:ixmax), yj(jymin:jymax), tcx, tcy,  &
+  &                    ioval(ixmin:ixmax,jymin:jymax),  &
+  &                    undef=0.0d0, undefg=0.0d0, undefgc='inc',  &
+  &                    axis='xy', stdopt=.true. )
+
+  deallocate(rad)
+  deallocate(theta)
+  deallocate(ioval_rt)
+  deallocate(cpval_rt)
+  deallocate(sp_rt)
+  deallocate(spout_rt)
+
+end subroutine azimuth_filter
+
+
 subroutine make_restart( itn, rtn, psik, zk, zopt )
 !-- output restart file
   use fft_saveval_define
@@ -436,8 +560,6 @@ subroutine fft_all_clear()
   psiko=0.0d0
   zko=0.0d0
   psikn=0.0d0
-  zkn=0.0d0
-  zkt=0.0d0
   zopt1=0.0d0
   uk=0.0d0
   vk=0.0d0
@@ -450,23 +572,6 @@ subroutine fft_all_clear()
   y=0.0d0
 !ORG  t=0.0d0
 
-  omegaxjbr=0.0d0
-  omegaxjnr=0.0d0
-  omegaxjbi=0.0d0
-  omegaxjni=0.0d0
-  omegayjbr=0.0d0
-  omegayjnr=0.0d0
-  omegayjbi=0.0d0
-  omegayjni=0.0d0
-  omegax1br=0.0d0
-  omegax1nr=0.0d0
-  omegax1bi=0.0d0
-  omegax1ni=0.0d0
-  omegay1br=0.0d0
-  omegay1nr=0.0d0
-  omegay1bi=0.0d0
-  omegay1ni=0.0d0
-
 end subroutine fft_all_clear
 
 
