@@ -13,7 +13,7 @@ program make_init
 !-- namelist variables
 
   integer :: nx, ny
-  integer :: nnum, mnum
+  integer :: nnum, wn(nc)
   real, allocatable, dimension(:) :: xr, yr
   double precision :: xmin, ymin, dx, dy
   double precision, dimension(nc) :: zetabar, zetap, rn, dn
@@ -22,10 +22,10 @@ program make_init
 !-- MT variables
   type(mt_state) :: mts, mts_tmp
   type(mt_state), allocatable, dimension(:) :: mtsn
-  integer, intrinsic :: time
+  integer, external :: time
   double precision, allocatable, dimension(:) :: mtv
 
-  integer :: i, j, k
+  integer :: i, j, k, mmax
   double precision :: r, theta
   double precision, dimension(nc) :: tcx, tcy
   double precision, allocatable, dimension(:) :: x, y
@@ -34,7 +34,7 @@ program make_init
 
   namelist /initial /nx, ny, xmin, ymin, dx, dy, fname,  &
   &                  tcx, tcy
-  namelist /vprof /zetabar, zetap, rn, dn, nnum, mnum, sig
+  namelist /vprof /zetabar, zetap, rn, dn, nnum, wn, sig
   read(5,nml=initial)
   read(5,nml=vprof)
 
@@ -44,8 +44,13 @@ program make_init
      stop
   end if
 
-  allocate(mtv(mnum))
-  allocate(mtsn(mnum))
+  mmax=wn(1)
+  do i=2,nnum
+     mmax=max(mmax,wn(i))
+  end do
+
+  allocate(mtv(mmax))
+  allocate(mtsn(mmax))
 
 !-- operating MT-19937
 
@@ -54,7 +59,7 @@ program make_init
   call new( mts )
   call init( mts, time() )
 
-  do i=1,mnum
+  do i=1,mmax
      mts_tmp=mts
      call create_stream( mts_tmp, mtsn(i), i )
      mtv(i)=genrand_double1( mtsn(i) )
@@ -113,8 +118,8 @@ program make_init
            theta=dabs(dacos(-1.0d0))
         end if
         zeta(i,j)=makez( r, theta, nnum, zetabar(1:nnum), zetap(1:nnum),  &
-  &                      rn(1:nnum-1), dn(1:nnum-1), sig(1:nnum),  &
-  &                      mnum, mtv )
+  &                      rn(1:nnum-1), dn(1:nnum-1), wn(1:nnum), sig(1:nnum),  &
+  &                      mmax, mtv )
      end do
   end do
 
@@ -152,8 +157,8 @@ end program
 
 
 
-double precision function makez( radi, ang, nnum, zbar, zp, rn, dn, sig,  &
-  &                              mnum, randp )
+double precision function makez( radi, ang, nnum, zbar, zp, rn, dn, wn, sig,  &
+  &                              mnum_max, randp )
 
   use Math_Const
 
@@ -166,16 +171,26 @@ double precision function makez( radi, ang, nnum, zbar, zp, rn, dn, sig,  &
   double precision :: zp(nnum)
   double precision :: rn(nnum-1)
   double precision :: dn(nnum-1)
+  integer :: wn(nnum)
   character(nnum) :: sig
-  integer :: mnum
-  double precision :: randp(mnum)
+  integer :: mnum_max
+  double precision :: randp(mnum_max)
   integer :: i, k
+  integer :: mnum
   double precision :: tmpz, FS, val, coe, s, s1, s2, zptmp
 
   FS(val)=1.0d0-3.0d0*(val**2)+2.0d0*(val**3)
 
   if(radi>=0.0d0.and.radi<rn(1)-dn(1))then
-     makez=zbar(1)
+     tmpz=0.0d0
+     mnum=wn(1)
+     if(mnum>0)then
+        do i=1,mnum
+           tmpz=tmpz+dcos(dble(i)*ang+randp(i)*2.0d0*pi_dp)
+        end do
+     end if
+
+     makez=zbar(1)+zp(1)*tmpz
 
   else if(radi>=rn(nnum-1)+dn(nnum-1))then
      makez=zbar(nnum)
@@ -185,6 +200,7 @@ double precision function makez( radi, ang, nnum, zbar, zp, rn, dn, sig,  &
         if(radi>=rn(k)-dn(k).and.radi<rn(k)+dn(k))then  ! Hermite
            tmpz=0.0d0
            zptmp=0.0d0
+           mnum=0
            coe=0.5d0/dn(k)
            s1=coe*(radi-rn(k)+dn(k))
            s2=coe*(rn(k)+dn(k)-radi)
@@ -194,15 +210,17 @@ double precision function makez( radi, ang, nnum, zbar, zp, rn, dn, sig,  &
               s=s2
               if(zp(k+1)/=0.0d0)then
                  zptmp=zp(k+1)
+                 mnum=wn(k+1)
               end if
            else if(sig(k:k)=='-')then
               s=s1
               if(zp(k)/=0.0d0)then
                  zptmp=zp(k)
+                 mnum=wn(k)
               end if
            end if
 
-           if(zptmp/=0.0d0)then
+           if((zptmp/=0.0d0).and.(mnum>0))then
               do i=1,mnum
                  tmpz=tmpz+dcos(dble(i)*ang+randp(i)*2.0d0*pi_dp)
               end do
@@ -219,7 +237,8 @@ double precision function makez( radi, ang, nnum, zbar, zp, rn, dn, sig,  &
         !   別エントリーにあるので, そもそも k=nnum-1 はこの else if に
         !   入ってこない.
               tmpz=0.0d0
-              if(zp(k+1)/=0.0d0)then
+              mnum=wn(k+1)
+              if((zp(k+1)/=0.0d0).and.(mnum>0))then
                  do i=1,mnum
                     tmpz=tmpz+dcos(dble(i)*ang+randp(i)*2.0d0*pi_dp)
                  end do
