@@ -1,9 +1,9 @@
 module saveval_alloc
-! ѿ
-! ѿ̾̿̾§
-! ¿ -> r,  -> i, ʣǿ -> c
-! ʿѾ -> b,  -> p
-! ȯŸ -> old, new
+! 変数の定義
+! 変数名の命名規則
+! 実数 -> r, 純虚数 -> i, 複素数 -> c
+! 平均場 -> b, 擾乱場 -> p
+! 時間発展 -> old, new
 
   use saveval_define
 
@@ -17,8 +17,8 @@ subroutine saveval_allocate()
 
   implicit none
 
-  allocate(x(nx))  ! ٥ȥưºɸ
-  allocate(y(ny))  ! ɸ
+  allocate(x(nx))  ! ベクトル動径座標
+  allocate(y(ny))  ! 接線座標
 
   allocate(xd(nxi))
   allocate(yd(nyi))
