@@ -1,5 +1,5 @@
 program solver
-! Nolan and Montgomery 2001 ǥ
+! Nolan and Montgomery 2001 の浅水モデル
   use gtool_history
   use Derivation
   use ffts
@@ -21,7 +21,7 @@ program solver
 !-- character values for MPI
   character(4) :: cpnum
 
-!-- do loop ѿ
+!-- do loop 用変数の定義
   integer :: i, j, it
 
 !-- Initializing MPI
@@ -33,7 +33,7 @@ program solver
   call MPI_COMM_RANK( MPI_COMM_WORLD, MY_RANK, IERROR )
   call MPI_COMM_SIZE( MPI_COMM_WORLD, PETOT, IERROR )
 
-!-- namelist ɤ߹
+!-- namelist の読み込み
 
   call read_name_mpi()
 
@@ -77,7 +77,7 @@ program solver
 
   call val_allocate()
 
-!-- Ͳ (2d ǡ 3 ǡؤγĥ)
+!-- 初期値化 (2d データから 3 次元データへの拡張)
 
   do i=1,nr
      ub(i)=0.0
@@ -95,18 +95,18 @@ program solver
   call HistoryGet( trim(finame), 'hbar', hib )
   call HistoryGet( trim(finame), 'r', ri )
 
-!-- time splitting method ˤ dtl, dts Υƥå׿Ψ׻
+!-- time splitting method における dtl, dts のステップ数の比率計算
 
   slratio=int(dtl/dts)
 
-!-- ʻκ
+!-- 格子点の再定義
   call val_coordinate_mpi()
 
-!-- bar Ⱦʻؤ
+!-- bar の半格子点への内挿
   call auto_interpolation_1d( ri, rv, vib, vb )
   call auto_interpolation_1d( ri, rs, hib, hb )
 
-!-- 쥤꡼ԥ
+!-- レイリーダンピング設定
   epsu=0.0
   epsv=0.0
   epsh=0.0
@@ -119,7 +119,7 @@ program solver
      end if
   end do
 
-!-- ͺ
+!-- 初期値作成
 
   do j=1,ntheta
      do i=1,nr
@@ -134,7 +134,7 @@ program solver
 
   write(*,*) "normally pass the initialization."
 
-!-- ϥեν
+!-- 出力ファイルの初期化
   call HistoryCreate( file=trim(foname), title='shallow result data', &
   & source='test', institution='test', dims=(/'r    ','theta', 't    '/),  &
   & dimsizes=(/nr,ntheta, 0/),  & 
@@ -155,7 +155,7 @@ program solver
 
   write(*,*) "time integration start."
 
-  !-- ν (ͤν)
+  !-- 出力等の処理 (初期値の出力)
   do j=1,ntheta
      do i=1,nr
         ucp_old(i,j)=urp_dmp(i,j)
@@ -193,19 +193,19 @@ program solver
 !$omp end do
 !$omp end parallel
 
-!-- solver 
+!-- solver スタート
 
   do it=1,nt
 
      call time_schematic( it )
 
-  !-- ƥåפοʤ߶
+  !-- ステップの進み具合出力
      if(MY_RANK==0)then
         write(*,*) "This step is ", it, "(time =", real(it)*dt, "[s])."
      end if
 
-     !-- ν (2)
-     if(mod(it,dmpstp)==0)then  ! ѴԤ¿Ϥ.
+     !-- 出力等の処理 (2)
+     if(mod(it,dmpstp)==0)then  ! 逆変換を行い実数出力する.
 
 !$omp parallel default(shared)
 !$omp do schedule(dynamic) private(i,j)
@@ -245,7 +245,7 @@ program solver
 
   end do
 
-!-- solver ȥå
+!-- solver ストップ
 
   if(MY_RANK==0)then
      write(*,*) "solver is normally."
