@@ -1,9 +1,9 @@
 module val_alloc
-! ѿ
-! ѿ̾̿̾§
-! ¿ -> r,  -> i, ʣǿ -> c
-! ʿѾ -> b,  -> p
-! ȯŸ -> old, new
+! 変数の定義
+! 変数名の命名規則
+! 実数 -> r, 純虚数 -> i, 複素数 -> c
+! 平均場 -> b, 擾乱場 -> p
+! 時間発展 -> old, new
 
   use val_define
   use read_namelist
@@ -17,19 +17,19 @@ subroutine val_allocate()
 
   implicit none
 
-  allocate(ri(nr))  ! 顼ưºɸ
-  allocate(rs(nr))  ! 顼ưºɸ
-  allocate(rv(nr))  ! ٥ȥưºɸ
-  allocate(theta(ntheta))  ! ɸ
-  allocate(hb(nr))  ! ݥƥ󥷥ʿѾ
-  allocate(ub(nr))  ! ưʿѾ
-  allocate(vb(nr))  ! ʿѾ
-  allocate(hib(nr))  ! ݥƥ󥷥ʿѾ
-  allocate(uib(nr))  ! ưʿѾ
-  allocate(vib(nr))  ! ʿѾ
-  allocate(dhbdr(nr))  ! ݥƥ󥷥ʿѾ
-  allocate(dubdr(nr))  ! ưʿѾ
-  allocate(dvbdr(nr))  ! ʿѾ
+  allocate(ri(nr))  ! スカラー動径座標初期値
+  allocate(rs(nr))  ! スカラー動径座標
+  allocate(rv(nr))  ! ベクトル動径座標
+  allocate(theta(ntheta))  ! 接線座標
+  allocate(hb(nr))  ! ジオポテンシャル平均場
+  allocate(ub(nr))  ! 動径風平均場
+  allocate(vb(nr))  ! 接線風平均場
+  allocate(hib(nr))  ! 初期ジオポテンシャル平均場
+  allocate(uib(nr))  ! 初期動径風平均場
+  allocate(vib(nr))  ! 初期接線風平均場
+  allocate(dhbdr(nr))  ! ジオポテンシャル平均場
+  allocate(dubdr(nr))  ! 動径風平均場
+  allocate(dvbdr(nr))  ! 接線風平均場
   allocate(ubdub(nr))
   allocate(ubdvb(nr))
   allocate(ubdhb(nr))
@@ -39,19 +39,19 @@ subroutine val_allocate()
   allocate(hbdub(nr))
   allocate(hbdvb(nr))
   allocate(hbdhb(nr))
-  allocate(epsu(nr))  ! 쥤꡼ԥ󥰷 u
-  allocate(epsv(nr))  ! 쥤꡼ԥ󥰷 v
-  allocate(epsh(nr))  ! 쥤꡼ԥ󥰷 h
+  allocate(epsu(nr))  ! レイリーダンピング係数 u
+  allocate(epsv(nr))  ! レイリーダンピング係数 v
+  allocate(epsh(nr))  ! レイリーダンピング係数 h
 !-- 2d val
-  allocate(urp_dmp(nr,ntheta))  ! ư® dmp
-  allocate(vrp_dmp(nr,ntheta))  ! ® dmp
-  allocate(hrp_dmp(nr,ntheta))  ! ݥƥ󥷥 dmp
-  allocate(urp_new(nr,ntheta))  ! ư® new
-  allocate(vrp_new(nr,ntheta))  ! ® new
-  allocate(hrp_new(nr,ntheta))  ! ݥƥ󥷥 new
-  allocate(uip_new(nr,ntheta))  ! ư® new
-  allocate(vip_new(nr,ntheta))  ! ® new
-  allocate(hip_new(nr,ntheta))  ! ݥƥ󥷥 new
+  allocate(urp_dmp(nr,ntheta))  ! 動径風速 dmp
+  allocate(vrp_dmp(nr,ntheta))  ! 接線風速 dmp
+  allocate(hrp_dmp(nr,ntheta))  ! ジオポテンシャル dmp
+  allocate(urp_new(nr,ntheta))  ! 動径風速 new
+  allocate(vrp_new(nr,ntheta))  ! 接線風速 new
+  allocate(hrp_new(nr,ntheta))  ! ジオポテンシャル new
+  allocate(uip_new(nr,ntheta))  ! 動径風速 new
+  allocate(vip_new(nr,ntheta))  ! 接線風速 new
+  allocate(hip_new(nr,ntheta))  ! ジオポテンシャル new
   allocate(durpdr(nr,ntheta))
   allocate(dvrpdr(nr,ntheta))
   allocate(dhrpdr(nr,ntheta))
@@ -61,20 +61,20 @@ subroutine val_allocate()
   allocate(coril(nr,ntheta))
 
 !-- complex, save part
-!-- žϤ٤, ˳դƤ
+!-- 回転行列はすべて, ここより先に割付しておく
 
-  allocate(ucp_dmp(nr,ntheta))  ! ư® old
-  allocate(vcp_dmp(nr,ntheta))  ! ® old
-  allocate(hcp_dmp(nr,ntheta))  ! ݥƥ󥷥 old
-  allocate(ucp_tmp(nr,ntheta))  ! ư® old
-  allocate(vcp_tmp(nr,ntheta))  ! ® old
-  allocate(hcp_tmp(nr,ntheta))  ! ݥƥ󥷥 old
-  allocate(ucp_old(nr,ntheta))  ! ư® old
-  allocate(vcp_old(nr,ntheta))  ! ® old
-  allocate(hcp_old(nr,ntheta))  ! ݥƥ󥷥 old
-  allocate(ucp_new(nr,ntheta))  ! ư® new
-  allocate(vcp_new(nr,ntheta))  ! ® new
-  allocate(hcp_new(nr,ntheta))  ! ݥƥ󥷥 new
+  allocate(ucp_dmp(nr,ntheta))  ! 動径風速 old
+  allocate(vcp_dmp(nr,ntheta))  ! 接線風速 old
+  allocate(hcp_dmp(nr,ntheta))  ! ジオポテンシャル old
+  allocate(ucp_tmp(nr,ntheta))  ! 動径風速 old
+  allocate(vcp_tmp(nr,ntheta))  ! 接線風速 old
+  allocate(hcp_tmp(nr,ntheta))  ! ジオポテンシャル old
+  allocate(ucp_old(nr,ntheta))  ! 動径風速 old
+  allocate(vcp_old(nr,ntheta))  ! 接線風速 old
+  allocate(hcp_old(nr,ntheta))  ! ジオポテンシャル old
+  allocate(ucp_new(nr,ntheta))  ! 動径風速 new
+  allocate(vcp_new(nr,ntheta))  ! 接線風速 new
+  allocate(hcp_new(nr,ntheta))  ! ジオポテンシャル new
   allocate(ducpdr(nr,ntheta))
   allocate(dvcpdr(nr,ntheta))
   allocate(dhcpdr(nr,ntheta))
@@ -126,11 +126,11 @@ subroutine val_allocate()
   allocate(forceua(nr,ntheta))  ! forceu
   allocate(forceva(nr,ntheta))  ! forcev
   allocate(forceha(nr,ntheta))  ! forceh
-  allocate(eup(nr,ntheta))  ! 쥤꡼ԥ󥰹 u
-  allocate(evp(nr,ntheta))  ! 쥤꡼ԥ󥰹 v
-  allocate(ehp(nr,ntheta))  ! 쥤꡼ԥ󥰹 h
-  allocate(corilu(nr,ntheta))  ! ꥪ u
-  allocate(corilv(nr,ntheta))  ! ꥪ v
+  allocate(eup(nr,ntheta))  ! レイリーダンピング項 u
+  allocate(evp(nr,ntheta))  ! レイリーダンピング項 v
+  allocate(ehp(nr,ntheta))  ! レイリーダンピング項 h
+  allocate(corilu(nr,ntheta))  ! コリオリ項 u
+  allocate(corilv(nr,ntheta))  ! コリオリ項 v
   allocate(fup(nr,jnt))
   allocate(fvp(nr,jnt))
   allocate(fhp(nr,jnt))
