@@ -1,5 +1,5 @@
 program SEQ
-! Pendergrass_Willoughby 2009 Υ䡼ꥢåǥ
+! Pendergrass_Willoughby 2009 のソーヤーエリアッセンモデル
   use derivation
   use Ellip_Slv
   use file_operate
@@ -18,15 +18,15 @@ program SEQ
   real :: dr, dz
   character(4) :: bc
   character(80) :: fname
-  character(80) :: sound_name  ! ǥ󥰥ե̾
+  character(80) :: sound_name  ! サウンディングファイルの名前
 
 !-- internal valiables
-  real, allocatable :: r(:)  ! ưºɸ
-  real, allocatable :: z(:)  ! ľɸ
-  real, allocatable :: v0(:,:)  ! ®
-  real, allocatable :: pres(:,:)  ! 
-  real, allocatable :: theta0(:,:)  ! 
-  real, allocatable :: exner0(:,:)  ! ʡؿ
+  real, allocatable :: r(:)  ! 動径座標
+  real, allocatable :: z(:)  ! 鉛直座標
+  real, allocatable :: v0(:,:)  ! 接線風速
+  real, allocatable :: pres(:,:)  ! 気圧
+  real, allocatable :: theta0(:,:)  ! 温位
+  real, allocatable :: exner0(:,:)  ! エクスナー関数
   real, allocatable :: rho(:,:)  ! 
   real, allocatable :: Q(:,:)  ! 
   real, allocatable :: buoterm(:,:)  ! 
@@ -67,19 +67,19 @@ program SEQ
   real, allocatable :: nu(:,:)  ! 
 
 !-- parameter
-  real, parameter :: Cd=1.5e-3  ! ư̸򴹷
+  real, parameter :: Cd=1.5e-3  ! 運動量交換係数
   real, parameter :: theta_const=273.16
-  real, parameter :: eps=1.0e4
+  real, parameter :: eps=1.0e4  ! original (Tsujino et al. 2017)
 
 !-- tmp valiables
   integer :: i, j
   real :: coriol
 
-!-- namelist Υѥ᡼
+!-- namelist からのパラメータの代入
   namelist /input /nr, nz, dr, dz, bc, fname, sound_name, coril, mom_flag
   read(5,nml=input)
 
-!-- γ
+!-- 配列の割り当て
   allocate(r(nr))
   allocate(z(nz))
   allocate(v0(nr,nz))
@@ -128,18 +128,18 @@ program SEQ
   coriol=2.0*omega*sin(coril*pi/180.0)
   bound=0.0
 
-!-- ɸͤ
+!-- 座標値の設定
 !  r=(/(dr*real(i-1),i=1,nr)/)
 !  z=(/(dz*real(i-1),i=1,nz)/)
 
-!-- ͤɤ߹
+!-- 初期値の読み込み
 
 !  call read_file( trim(fname), nr, nz, 1, v0 )
 !  call read_file( trim(fname), nr, nz, 2, p0 )
 !  call read_file( trim(fname), nr, nz, 3, Q )
 !  call read_file( trim(fname), nr, nz, 4, v0 )
 
-!-- gtool ˤɤ߹
+!-- gtool による読み込み
 
   call HistoryGet( trim(fname), 'r', r(1:nr) )
   call HistoryGet( trim(fname), 'z', z(1:nz) )
@@ -149,21 +149,21 @@ program SEQ
   call HistoryGet( trim(fname), 'v', v0(1:nr,1:nz) )
   call HistoryGet( trim(fname), 'rho', rho(1:nr,1:nz) )
 
-!-- Q ǮΨºݤη׻ɬפϤ˴.
+!-- Q を過熱率から実際の計算で必要な浮力に換算.
   do j=1,nz
      do i=1,nr
         Q(i,j)=Q(i,j)*g/Cpd/theta0(i,j)
      end do
   end do
 
-!-- ư̥η׻
+!-- 運動量ソースの計算
 
   mom=0.0
 
   select case (mom_flag)
   case (0)
      write(*,*) "### momentum source is zero."
-  case (1)  ! ®پ줫׻.
+  case (1)  ! 速度場から計算する.
      write(*,*) "### momentum source is calculating with Vt."
      dmomdz=0.0
      nu=0.0
@@ -198,8 +198,8 @@ program SEQ
         tauz(i,1)=Cd*abs(v0(i,1))*v0(i,1)
      end do
 
-!-- ޤǤ, ϥƥ󥽥η׻λ.
-!-- ʹߤήեåη׻.
+!-- ここまでで, 応力テンソルの計算終了.
+!-- 以降で乱流フラックスの計算.
 
      do i=1,nr
         call grad_1d( z, tauz(i,:), dmomdz(i,:) )
@@ -233,7 +233,7 @@ program SEQ
 
   end select
 
-!-- ʪ̤η׻
+!-- 基本物理量の計算
   do j=1,nz
      do i=1,nr
         exner0(i,j)=exner_func_dry( pres(i,j) )
@@ -255,13 +255,13 @@ program SEQ
      end do
   end do
 
-!-- ʪ̤θ۷׻
+!-- 物理量の勾配計算
   do i=1,nr
      call grad_1d( z, rho(i,:), drhodz(i,:) )
      call grad_1d( z, gamma(i,:), dgammadz(i,:) )
      call grad_1d( z, v0(i,:), S(i,:) )
      call grad_1d( z, theta0(i,:), N2(i,:) )
-     do j=1,nz  ! buoterm ľܷ׻ΤǤϤʤ, ֥ȿư׻.
+     do j=1,nz  ! buoterm を直接計算するのではなく, ブラント振動を計算する.
         N2(i,j)=(g/theta0(i,j))*N2(i,j)
      end do
      call grad_1d( z, Q(i,:), dQdz(i,:) )
@@ -272,14 +272,14 @@ program SEQ
      call grad_1d( r, rho(:,j), drhodr(:,j) )
      call grad_1d( r, gamma(:,j), dgammadr(:,j) )
      call grad_1d( r, theta0(:,j), Buo(:,j) )
-     do i=1,nr  ! buoterm ľܷ׻ΤǤϤʤ, ֥ȿư׻.
+     do i=1,nr  ! buoterm を直接計算するのではなく, ブラント振動を計算する.
         Buo(i,j)=(g/theta0(i,j))*Buo(i,j)
      end do
      call grad_1d( r, v0(:,j), dv0dr(:,j) )
      call grad_1d( r, Q(:,j), dQdr(:,j) )
   end do
 
-!-- ʪ̤η׻
+!-- 各物理量の計算
   do j=1,nz
      do i=1,nr
         Hrho_inv(i,j)=drhodz(i,j)/rho(i,j)
@@ -297,7 +297,7 @@ program SEQ
      end do
   end do
 
-!-- Ϥγƹ෸η׻
+!-- 方程式系の各項係数の計算
   do j=1,nz
      do i=1,nr
         term1(i,j)=abs(N2(i,j))
@@ -324,7 +324,7 @@ do j=1,nr
 write(*,*) gamma(j,2)
 end do
 
-!-- ݥ󥽥
+!-- ポアソンソルバ
 
   call Ellip_Jacobi_2d( r(1:nr), z(1:nz), force(1:nr,1:nz), eps,  &
   &                     bc, psi(1:nr,1:nz), bound(1:nr,1:nz),  &
@@ -332,7 +332,7 @@ end do
   &                     c=term3(1:nr,1:nz),  d=term4(1:nr,1:nz),  &
   &                     e=term5(1:nr,1:nz)) 
 
-!-- ήؿ 2 ۴Ĥη׻
+!-- 質量流線関数から 2 次循環の計算
 
   do i=1,nr
      call grad_1d( z, psi(i,:), u2(i,:) )
@@ -354,13 +354,13 @@ end do
      end do
   end do
 
-!-- եؤν񤭽Ф
+!-- ファイルへの書き出し
 
 !  call write_file( trim(output_fname), nr, nz, 1, psi )
 !  call write_file( trim(output_fname), nr, nz, 2, u2, mode='old' )
 !  call write_file( trim(output_fname), nr, nz, 3, w2, mode='old' )
 
-!-- gtool ˤ񤭽Ф
+!-- gtool による書き出し
 
   call HistoryCreate( file='result_'//trim(fname), title='SEQ result data', &
     & source='test', institution='test', dims=(/'r','z'/), dimsizes=(/nr,nz/),  &
@@ -393,7 +393,7 @@ end do
   call HistoryClose
 
 write(*,*) "mom", mom
-!-- λ
+!-- 終了宣言
 
   write(*,*) "Program is terminated, normally."
 
