@@ -1,7 +1,7 @@
 module time_scheme
-! ֥ऴȤ˷׻Ԥ⥸塼
-! force_solv Ƿ׻ͤ򥹥˹碌Ƴ꿶,
-! ֥ƥåפȯŸ.
+! 時間スキームごとに計算を行うモジュール
+! force_solv で計算した強制項の値をスキームに合わせて割り振り,
+! 時間ステップを発展させる.
   use Derivation
   use Ellip_Slv
   use max_min
@@ -24,7 +24,7 @@ contains
 subroutine time_schematic( step, mode )
 
   implicit none
-  integer, intent(in) :: step  ! ॹƥåֹ
+  integer, intent(in) :: step  ! タイムステップ番号
   character(1), intent(in) :: mode  ! time splitting mode : 's' = small, 'b' = large
   integer :: ct, i, j, k
   real :: dt, pres
@@ -37,9 +37,9 @@ subroutine time_schematic( step, mode )
 
   if(mode(1:1)=='b')then
      select case (time_flag(1:1))
-     case ('1')  ! RK4 
+     case ('1')  ! RK4 スキーム
 
-     !-- ѿι
+     !-- 変数の更新
         do j=1,nz+1
            do i=1,nr+1
               u_tmp(i,j)=u_new(i,j)
@@ -61,7 +61,7 @@ subroutine time_schematic( step, mode )
            end do
         end do
 
-     !-- RK4 ΤȤΤѤѿν force_solv ȤΩ RK4 ΤȤΤư.
+     !-- RK4 のときのみ用いる全強制変数の初期化 force_solv とは独立で RK4 のときのみ動作する.
 
         call real_init( forcea_v )
         call real_init( forcea_t )
@@ -69,13 +69,13 @@ subroutine time_schematic( step, mode )
         call real_init( forcea_qc )
         call real_init( forcea_ql )
 
-        do ct=1,4  ! RK4 η򤽤줾׻
+        do ct=1,4  ! RK4 の傾きをそれぞれ計算
 
-        !-- ׻.
+        !-- 強制項を計算.
 
            call force( mode )
 
-!--  ʬ (RK4 ˡ)
+!--  時間積分 (RK4 法)
            select case (ct)
            case (1)
 
@@ -225,53 +225,53 @@ subroutine time_schematic( step, mode )
 
         end do
 
-     case ('2')  ! Leap Frog 
+     case ('2')  ! Leap Frog スキーム
 
         if(step==1)then
            do j=1,nz+1
               do i=1,nr+1
-                 u_tmp(i,j)=u_new(i,j)  ! old ()  tmp (1 ƥå) .
-                 v_tmp(i,j)=v_new(i,j)  ! old ()  tmp (1 ƥå) .
-                 w_tmp(i,j)=w_new(i,j)  ! old ()  tmp (1 ƥå) .
-                 p_tmp(i,j)=p_new(i,j)  ! old ()  tmp (1 ƥå) .
-                 t_tmp(i,j)=t_new(i,j)  ! old ()  tmp (1 ƥå) .
-                 qv_tmp(i,j)=qv_new(i,j)  ! old ()  tmp (1 ƥå) .
-                 qc_tmp(i,j)=qc_new(i,j)  ! old ()  tmp (1 ƥå) .
-                 ql_tmp(i,j)=ql_new(i,j)  ! old ()  tmp (1 ƥå) .
-                 u_old(i,j)=u_new(i,j)  ! new (1 ƥå)  old () .
-                 v_old(i,j)=v_new(i,j)  ! new (1 ƥå)  old () .
-                 w_old(i,j)=w_new(i,j)  ! new (1 ƥå)  old () .
-                 p_old(i,j)=p_new(i,j)  ! new (1 ƥå)  old () .
-                 t_old(i,j)=t_new(i,j)  ! new (1 ƥå)  old () .
-                 qv_old(i,j)=qv_new(i,j)  ! new (1 ƥå)  old () .
-                 qc_old(i,j)=qc_new(i,j)  ! new (1 ƥå)  old () .
-                 ql_old(i,j)=ql_new(i,j)  ! new (1 ƥå)  old () .
+                 u_tmp(i,j)=u_new(i,j)  ! old (今) を tmp (1 ステップ前) に.
+                 v_tmp(i,j)=v_new(i,j)  ! old (今) を tmp (1 ステップ前) に.
+                 w_tmp(i,j)=w_new(i,j)  ! old (今) を tmp (1 ステップ前) に.
+                 p_tmp(i,j)=p_new(i,j)  ! old (今) を tmp (1 ステップ前) に.
+                 t_tmp(i,j)=t_new(i,j)  ! old (今) を tmp (1 ステップ前) に.
+                 qv_tmp(i,j)=qv_new(i,j)  ! old (今) を tmp (1 ステップ前) に.
+                 qc_tmp(i,j)=qc_new(i,j)  ! old (今) を tmp (1 ステップ前) に.
+                 ql_tmp(i,j)=ql_new(i,j)  ! old (今) を tmp (1 ステップ前) に.
+                 u_old(i,j)=u_new(i,j)  ! new (1 ステップ先) を old (今) に.
+                 v_old(i,j)=v_new(i,j)  ! new (1 ステップ先) を old (今) に.
+                 w_old(i,j)=w_new(i,j)  ! new (1 ステップ先) を old (今) に.
+                 p_old(i,j)=p_new(i,j)  ! new (1 ステップ先) を old (今) に.
+                 t_old(i,j)=t_new(i,j)  ! new (1 ステップ先) を old (今) に.
+                 qv_old(i,j)=qv_new(i,j)  ! new (1 ステップ先) を old (今) に.
+                 qc_old(i,j)=qc_new(i,j)  ! new (1 ステップ先) を old (今) に.
+                 ql_old(i,j)=ql_new(i,j)  ! new (1 ステップ先) を old (今) に.
               end do
            end do
         else
            do j=1,nz+1
               do i=1,nr+1
-                 u_tmp(i,j)=u_old(i,j)  ! old ()  tmp (1 ƥå) .
-                 v_tmp(i,j)=v_old(i,j)  ! old ()  tmp (1 ƥå) .
-                 w_tmp(i,j)=w_old(i,j)  ! old ()  tmp (1 ƥå) .
-                 p_tmp(i,j)=p_old(i,j)  ! old ()  tmp (1 ƥå) .
-                 t_tmp(i,j)=t_old(i,j)  ! old ()  tmp (1 ƥå) .
-                 qv_tmp(i,j)=qv_old(i,j)  ! old ()  tmp (1 ƥå) .
-                 qc_tmp(i,j)=qc_old(i,j)  ! old ()  tmp (1 ƥå) .
-                 ql_tmp(i,j)=ql_old(i,j)  ! old ()  tmp (1 ƥå) .
-                 u_old(i,j)=u_new(i,j)  ! new (1 ƥå)  old () .
-                 v_old(i,j)=v_new(i,j)  ! new (1 ƥå)  old () .
-                 w_old(i,j)=w_new(i,j)  ! new (1 ƥå)  old () .
-                 p_old(i,j)=p_new(i,j)  ! new (1 ƥå)  old () .
-                 t_old(i,j)=t_new(i,j)  ! new (1 ƥå)  old () .
-                 qv_old(i,j)=qv_new(i,j)  ! new (1 ƥå)  old () .
-                 qc_old(i,j)=qc_new(i,j)  ! new (1 ƥå)  old () .
-                 ql_old(i,j)=ql_new(i,j)  ! new (1 ƥå)  old () .
+                 u_tmp(i,j)=u_old(i,j)  ! old (今) を tmp (1 ステップ前) に.
+                 v_tmp(i,j)=v_old(i,j)  ! old (今) を tmp (1 ステップ前) に.
+                 w_tmp(i,j)=w_old(i,j)  ! old (今) を tmp (1 ステップ前) に.
+                 p_tmp(i,j)=p_old(i,j)  ! old (今) を tmp (1 ステップ前) に.
+                 t_tmp(i,j)=t_old(i,j)  ! old (今) を tmp (1 ステップ前) に.
+                 qv_tmp(i,j)=qv_old(i,j)  ! old (今) を tmp (1 ステップ前) に.
+                 qc_tmp(i,j)=qc_old(i,j)  ! old (今) を tmp (1 ステップ前) に.
+                 ql_tmp(i,j)=ql_old(i,j)  ! old (今) を tmp (1 ステップ前) に.
+                 u_old(i,j)=u_new(i,j)  ! new (1 ステップ先) を old (今) に.
+                 v_old(i,j)=v_new(i,j)  ! new (1 ステップ先) を old (今) に.
+                 w_old(i,j)=w_new(i,j)  ! new (1 ステップ先) を old (今) に.
+                 p_old(i,j)=p_new(i,j)  ! new (1 ステップ先) を old (今) に.
+                 t_old(i,j)=t_new(i,j)  ! new (1 ステップ先) を old (今) に.
+                 qv_old(i,j)=qv_new(i,j)  ! new (1 ステップ先) を old (今) に.
+                 qc_old(i,j)=qc_new(i,j)  ! new (1 ステップ先) を old (今) に.
+                 ql_old(i,j)=ql_new(i,j)  ! new (1 ステップ先) を old (今) に.
               end do
            end do
         end if
 
-     !-- ׻.
+     !-- 強制項を計算.
 
         call force( mode )
 
@@ -350,7 +350,7 @@ subroutine time_schematic( step, mode )
 
      if(step==1)then
 
-     !-- ѿι
+     !-- 変数の更新
         do j=1,nz+1
            do i=1,nr+1
               u_old(i,j)=u_new(i,j)
@@ -368,7 +368,7 @@ subroutine time_schematic( step, mode )
 
      else
 
-     !-- ѿι
+     !-- 変数の更新
         do j=1,nz+1
            do i=1,nr+1
               u_old(i,j)=u_new(i,j)
