@@ -1,7 +1,8 @@
 module Dcl_Thermo_Graph
-! ǮϳشطΥդμư롼
+! 熱力学関係のグラフの自動化ルーチン
   use Thermo_Const
   use Thermo_Function
+  use Thermo_Advanced_Function
   use Statistics
   use dcl
   use Basis
@@ -10,69 +11,76 @@ contains
 
 subroutine SkewT( title, slope, t_int, p_int,  &
   &               sondeT, sondeP, sondeQV,  &
-  &               sondeZ, viewx_int, viewy_int, undef, no_frame, refh )
-! skew-T 롼
-! ȽļΥȥϤ٤ height  temperature Ǹ.
+  &               sondeZ, viewx_int, viewy_int, undef, no_frame, refh,  &
+  &               heiopt, septlopt )
+! skew-T ダイアグラムを作成するルーチン
+! 横軸と縦軸のタイトルはすべて height と temperature で固定.
   use Thermo_Const
   implicit none
-  character(*), intent(in) :: title  ! ɽΥȥ
-  real, intent(in) :: slope  ! skewT η
-  real, intent(in) :: t_int(2)  ! ʲ١ˤξü [K]
+  character(*), intent(in) :: title  ! 表のタイトル
+  real, intent(in) :: slope  ! skewT の傾き具合
+  real, intent(in) :: t_int(2)  ! 横軸（温度）の両端値 [K]
                       ! t_int(1)=tmin, t_int(2)=tmax
-  real, intent(in) :: p_int(2)  ! ļʵˤξü [Pa]
+  real, intent(in) :: p_int(2)  ! 縦軸（気圧）の両端値 [Pa]
                       ! p_int(1)=pmin, p_int(2)=pmax
-                      ! sondeZ Ϳ, ΰ
-                      ! p_int(1)=zmin, p_int(2)=zmax .
-  real, intent(in), dimension(:) :: sondeT  ! Ǥβ [K]
-  real, intent(in), dimension(size(sondeT)) :: sondeP  ! Ǥε [Pa]
-  real, intent(in), dimension(size(sondeT)) :: sondeQV  ! Ǥκ [kg/kg]
-  real, intent(in), dimension(size(sondeT)), optional :: sondeZ  ! Ǥι [m]
-  ! sondeP : logP ǽļȤ. ΤȤ, pmin, pmax, sondeP Ϥ٤
-  !           Pa ñ̤ǤȤ뤳.
-  ! sondeZ(optional) : geometric z ǽļȤ.
-  !                    ΤȤ, pmin, pmax ϵǤϤʤ, 
-  !                    褷 [m] κǾͤͿ.
-  ! z=-logP δطˤʤ뤬, ǽΤ, ѼԤ
-  ! ˤ, min Ϻ, max Ϻͤ OK.
-  ! ǥեȤǤ, ǽļ.
-  real, intent(in), optional :: viewx_int(2)  ! viewport  x ξü.
+                      ! sondeZ が与えられる場合は, この引数は
+                      ! p_int(1)=zmin, p_int(2)=zmax を入れる.
+  real, intent(in), dimension(:) :: sondeT  ! ゾンデの温度 [K]
+  real, intent(in), dimension(size(sondeT)) :: sondeP  ! ゾンデの気圧 [Pa]
+  real, intent(in), dimension(size(sondeT)) :: sondeQV  ! ゾンデの混合比 [kg/kg]
+  real, intent(in), dimension(size(sondeT)) :: sondeZ  ! ゾンデの高度 [m]
+  ! sondeP : logP で縦軸をとる. このとき, pmin, pmax, sondeP はすべて
+  !          気圧を Pa 単位でとること.
+  ! sondeZ(optional) : geometric z で縦軸をとる.
+  !                    このとき, pmin, pmax は気圧ではなく, 
+  !                    描画したい高度 [m] の最小最大値を与える.
+  ! z=-logP の関係になるが, それは内部で処理するので, 使用者は
+  ! 気にせず, min は最低値, max は最大値を入れれば OK.
+  ! デフォルトでは, 気圧で縦軸設定.
+  real, intent(in), optional :: viewx_int(2)  ! viewport の x 方向の両端.
                                 ! viewx_int(1)=viewxmin, viewx_int(2)=viewxmax
-  real, intent(in), optional :: viewy_int(2)  ! viewport  y ξü.
+  real, intent(in), optional :: viewy_int(2)  ! viewport の y 方向の両端.
                                 ! viewy_int(1)=viewymin, viewy_int(2)=viewymax
-  ! ǥեȤ, (0.25, 0.7, 0.2, 0.8) Ǹ.
-  real, intent(in), optional :: undef  ! ̤, ǥեȤǤꤷʤ.
-  logical, intent(in), optional :: no_frame  ! NewFrame ƤФʤ
-                                   ! .false. = Ƥ. .true. = ƤФ NewFig.
-                                   ! ǥեȤ .false.
-  real, intent(in), optional :: refh  ! reference pressure (or height in sondeZ) of moist adiabat
-!-- ʾ, 
-  real :: tmin  ! ʲ١ˤκ [K]
-  real :: tmax  ! ʲ١ˤκǹ [K]
-  real :: pmin  ! ļʵˤκ [Pa]
-  real :: pmax  ! ļʵˤκǹ [Pa]
-  real :: zmin  ! ļʹ١ˤκ [m]
-  real :: zmax  ! ļʹ١ˤκǹ [m]
-  real :: vxmin  ! viewport  xmin.
-  real :: vxmax  ! viewport  xmin.
-  real :: vymin  ! viewport  xmin.
-  real :: vymax  ! viewport  xmin.
-!-- ʾ, ֤ѿ
+  ! デフォルトは, (0.25, 0.7, 0.2, 0.8) で固定.
+  real, intent(in), optional :: undef  ! 未定義値, デフォルトでは設定しない.
+  logical, intent(in), optional :: no_frame  ! NewFrame を呼ばない
+                                   ! .false. = 呼ぶ. .true. = 呼ばずに NewFig.
+                                   ! デフォルトは .false.
+  real, intent(in), optional :: refh  ! reference pressure (or height) of moist adiabat
+  logical, intent(in), optional :: heiopt  ! reference height flag (default false=pressure)
+  logical, intent(in), optional :: septlopt  ! 観測の湿潤断熱線を描くか
+                                             ! .true.: 描く, .false.: 描かない
+                                             ! (default: .true.)
+!-- 以上, 引数
+  real :: tmin  ! 横軸（温度）の最低値 [K]
+  real :: tmax  ! 横軸（温度）の最高値 [K]
+  real :: pmin  ! 縦軸（気圧）の最低値 [Pa]
+  real :: pmax  ! 縦軸（気圧）の最高値 [Pa]
+  real :: zmin  ! 縦軸（高度）の最低値 [m]
+  real :: zmax  ! 縦軸（高度）の最高値 [m]
+  real :: vxmin  ! viewport の xmin.
+  real :: vxmax  ! viewport の xmin.
+  real :: vymin  ! viewport の xmin.
+  real :: vymax  ! viewport の xmin.
+!-- 以上, 引数の置き換え用変数
   integer, parameter :: nx=100, ny=100
-  real, dimension(nx) :: septc, tempc
+  integer :: ncl_q=9
+  real, dimension(nx) :: ptc, septc, tempc
   real, dimension(nx,ny) :: temp, pt, qvs, spt
   real, dimension(size(sondeT)) :: sondedT, sondedP, sondedTD, sondedSEPT
   real, dimension(size(sondeT)) :: sondeRP
   real, dimension(nx) :: tempd
   real, dimension(ny) :: p, z
-  integer :: i, j, k, nt, i_z, i_p, i_sept
+  real, dimension(20) :: qvc
+  integer :: i, j, k, nt, i_z, i_zlcl, i_p, i_sept
   real :: pdmax, pdmin
   real :: dp, dt
   real :: undeff
   real :: slope_param, dz
-  real :: refp, reft, refsept
-  logical :: heiopt_z, no_frame_flag, moist_flag
+  real :: refz, refp, reft, refqv, refpt, refsept
+  real :: reftlcl, refzlcl, refplcl, tmpsiz
+  logical :: heiopt_z, no_frame_flag, moist_flag, septl_flag
 
-  heiopt_z=.false.
   nt=size(sondeT)
 
   if(present(undef))then
@@ -81,11 +89,23 @@ subroutine SkewT( title, slope, t_int, p_int,  &
      undeff=-999.0
   end if
 
-!-- DCL 
-!  call SGLSET('LCLIP',.true.)  ! åԥ󥰽
+  if(present(heiopt))then
+     heiopt_z=heiopt
+  else
+     heiopt_z=.false.
+  end if
+
+  if(present(septlopt))then
+     septl_flag=septlopt
+  else
+     septl_flag=.true.
+  end if
+
+!-- DCL 前設定
+!  call SGLSET('LCLIP',.true.)  ! クリッピング処理
   call DclSetParm( 'ENABLE_CONTOUR_MESSAGE', .false. )
 
-!-- ʹ, ץ
+!-- 以降, オプション処理
   if(present(viewx_int))then
      vxmin=viewx_int(1)
      vxmax=viewx_int(2)
@@ -108,6 +128,9 @@ subroutine SkewT( title, slope, t_int, p_int,  &
      no_frame_flag=.false.
   end if
 
+!-- qvs の等値線間隔を設定
+  qvc(1:ncl_q)=(/0.1, 0.2, 0.5, 1.0, 2.0, 5.0, 10.0, 15.0, 20.0/)
+
 !-- reverse pressure for interpo_search_1d
 
   do i=1,nt
@@ -118,7 +141,7 @@ subroutine SkewT( title, slope, t_int, p_int,  &
      end if
   end do
 
-!-- ֤ѿ֤
+!-- 引数の置き換え用変数に置き換え
   pmin=p_int(1)
   pmax=p_int(2)
   tmin=t_int(1)
@@ -127,8 +150,8 @@ subroutine SkewT( title, slope, t_int, p_int,  &
   dt=(tmax-tmin)/(nx-1)
   tempd=(/((tmin+dt*(i-1)),i=1,nx)/)
 
-  if(present(sondeZ))then
-     ! ٷ׻, z  p ľʤ pt η׻Բǽ (׽)
+  if(heiopt_z.eqv..true.)then
+     ! 高度計算した場合, z を p に直さないと pt の計算不可能 (要修正)
      zmin=pmin
      zmax=pmax
      call interpo_search_1d( sondeZ, zmin, i_z )
@@ -136,12 +159,10 @@ subroutine SkewT( title, slope, t_int, p_int,  &
      call interpo_search_1d( sondeZ, zmax, i_z )
      call interpolation_1d( sondeZ(i_z:i_z+1), sondeP(i_z:i_z+1), zmax, pmax )
 
-     heiopt_z=.true.
-
      dz=(zmax-zmin)/(ny-1)
      z=(/((zmin+dz*(i-1)),i=1,ny)/)
-     slope_param=1.0/(zmax-zmin)   ! ׻Ĵ᷸.
-                                   ! , ٤ 1 Ȥʤ褦˵ʲ
+     slope_param=1.0/(zmax-zmin)   ! 傾き計算の調節係数.
+                                   ! だいたい, 最大高度で 1 となるように規格化
      do i=1,ny
         call interpo_search_1d( sondeZ, z(i), i_z )
         call interpolation_1d( z(i_z:i_z+1), sondeP(i_z:i_z+1), z(i), p(i) )
@@ -157,27 +178,41 @@ subroutine SkewT( title, slope, t_int, p_int,  &
   end if
 
 !-- drawing moist adiabat line (option)
+!-- 1. determine TLCL and ZLCL at refh.
+!-- 2. draw from refh to ZLCL along the dry adiabat (pt)
+!-- 3. draw from ZLCL to upper bound along the moist adiabat (sept)
 
   if(present(refh))then
      moist_flag=.true.
      if(heiopt_z.eqv..true.)then
-        call interpo_search_1d( sondeZ, refh, i_z )
+        refz=refh
+        call interpo_search_1d( sondeZ, refz, i_z )
         call interpolation_1d( sondeZ(i_z:i_z+1), sondeP(i_z:i_z+1),  &
-  &                            refh, refp )
-        call interpolation_1d( sondeZ(i_z:i_z+1), sondeT(i_z:i_z+1),  &
-  &                            refh, reft )
-        refsept=thetaes_Bolton( reft, refp )
+  &                            refz, refp )
      else
-        call interpo_search_1d( sondeRP, -refh, i_z )
-        call interpolation_1d( sondeRP(i_z:i_z+1), sondeT(i_z:i_z+1),  &
-  &                            -refh, reft )
-        refsept=thetaes_Bolton( reft, refh )
+        refp=refh
+        call interpo_search_1d( sondeRP, -refp, i_z )
+        call interpolation_1d( sondeRP(i_z:i_z+1), sondeZ(i_z:i_z+1),  &
+  &                            -refp, refz )
      end if
+
+     call interpolation_1d( sondeZ(i_z:i_z+1), sondeQV(i_z:i_z+1),  &
+  &                         refz, refqv )
+     call interpolation_1d( sondeZ(i_z:i_z+1), sondeT(i_z:i_z+1),  &
+  &                         refz, reft )
+     refpt=theta_dry( reft, refp )
+     reftlcl=TqvP_2_TLCL( reft, refqv, refp )
+     refzlcl=z_LCL( refz, sondeZ, sondeT, sondeP, sondeQV, undeff=undeff )
+
+     call interpo_search_1d( sondeZ, refzlcl, i_zlcl )
+     call interpolation_1d( sondeZ(i_zlcl:i_zlcl+1), sondeP(i_zlcl:i_zlcl+1),  &
+  &                         refzlcl, refplcl )
+     refsept=thetaes_Bolton( reftlcl, refplcl )  ! At ZLCL
   else
      moist_flag=.false.
   end if
 
-!-- ƶη׻
+!-- 各曲線の計算
   do j=1,ny
      do i=1,nx
         if(heiopt_z.eqv..true.)then
@@ -207,13 +242,24 @@ subroutine SkewT( title, slope, t_int, p_int,  &
                  tempc(i)=tmin+dt*real(i-1)+slope*log(sondeP(j)/p0)
               end if
               septc(i)=thetaes_Bolton( tempc(i), sondeP(j) )
+              ptc(i)=theta_dry( tempc(i), sondeP(j) )
            end do
-           call interpo_search_1d( septc(:), refsept, i_sept )
+           if(refzlcl<=sondeZ(j))then  ! dry adiabat (pt) below ZLCL
+              call interpo_search_1d( septc(:), refsept, i_sept )
+           else  ! moist adiabat (sept) above ZLCL
+              call interpo_search_1d( ptc(:), refpt, i_sept )
+           end if
            if(i_sept>0)then
               if(i_sept<nx)then
-                 call interpolation_1d( septc(i_sept:i_sept+1),  &
-  &                                     tempc(i_sept:i_sept+1),  &
-  &                                     refsept, sondedSEPT(j) )
+                 if(refzlcl<=sondeZ(j))then  ! dry adiabat (pt) below ZLCL
+                    call interpolation_1d( septc(i_sept:i_sept+1),  &
+  &                                        tempc(i_sept:i_sept+1),  &
+  &                                        refsept, sondedSEPT(j) )
+                 else  ! moist adiabat (sept) above ZLCL
+                    call interpolation_1d( ptc(i_sept:i_sept+1),  &
+  &                                        tempc(i_sept:i_sept+1),  &
+  &                                        refpt, sondedSEPT(j) )
+                 end if
               else
                  sondedSEPT(j)=tempc(nx)
               end if
@@ -232,10 +278,10 @@ subroutine SkewT( title, slope, t_int, p_int,  &
         !-- calculating sounding thetaes to here
 
         if(heiopt_z.eqv..true.)then
-           sondedT(j)=sondeT(j)+slope*sondeZ(j)*slope_param  ! 2000 ǳ뺬Ϥʤ.
+           sondedT(j)=sondeT(j)+slope*sondeZ(j)*slope_param  ! 2000 で割る根拠はない.
            sondedTD(j)=es_TD(qvP_2_e(sondeQV(j),sondeP(j)))+slope*sondeZ(j)*slope_param
         else
-           sondedT(j)=sondeT(j)-slope*log(sondeP(j)/p0)  ! temp, tempd Ʊ.
+           sondedT(j)=sondeT(j)-slope*log(sondeP(j)/p0)  ! temp, tempd の操作と同じ.
            sondedTD(j)=es_TD(qvP_2_e(sondeQV(j),sondeP(j)))-slope*log(sondeP(j)/p0)
         end if
      end if
@@ -263,88 +309,105 @@ subroutine SkewT( title, slope, t_int, p_int,  &
   call DclSetViewPort( vxmin, vxmax, vymin, vymax )
   call DclSetTransFunction
 
+  CALL UZLSET( 'LABELYL', .TRUE. )
+
   if(heiopt_z.eqv..true.)then
-     call DclSetTitle( 'Temperature', 'height', '', '' )
+     call DclSetTitle( 'Temperature', 'Height', 'K', 'm' )
+     call DclDrawScaledAxis
   else
-     call DclSetTitle( 'Temperature', 'pressure', '', '' )
+     call DclSetTitle( 'Temperature', 'Pressure', 'K', 'hPa' )
+     CALL USCSET( 'CYFMT', '(f5.0)' )
+     call DclDrawAxis( 'rl', 100.0, 25.0 )
+     call DclDrawScaledAxis( 'bt' )
   end if
 
-  call DclDrawScaledAxis
 !  call DclDrawAxis( 'v', pdmax/40.0, pdmax/10.0, section=vxmin )
 !  call DclDrawAxis( 'v', pdmax/40.0, pdmax/10.0, section=vxmax )
 
   call UDISET('INDXMJ', 31) ! ORIG = 34
   call UDISET('INDXMN', 31)
   call DclDrawContour( temp )
+
   call UDISET('INDXMJ', 21)
   call UDISET('INDXMN', 21)
   call DclDrawContour( pt )
+
   call UDISET('INDXMJ', 11)
   call UDISET('INDXMN', 11)
   call DclDrawContour( spt )
-  call UDISET('INDXMJ', 1)
+
+!  call UDISET('INDXMJ', 1)
+  call DclGetParm( 'RSIZEL', tmpsiz )
+  do i=1,ncl_q
+     call DclSetContourLine( qvc(i), index=11, type=3,  &
+  &                          label=trim(adjustl(r2c_convert(qvc(i),forma='(f4.1)'))),  &
+  &                          height=tmpsiz )
+  end do
   call DclDrawContour( qvs )
+  call UDICLV  ! qvs で設定した等値線設定を初期化する
   call DclDrawLine( sondedT, sondedP, index=45 )
   call DclDrawLine( sondedTD, sondedP, index=45, type=2 )
-  call DclDrawLine( sondedSEPT, sondedP, index=45, type=3 )
+  if(septl_flag.eqv..true.)then
+     call DclDrawLine( sondedSEPT, sondedP, index=45, type=3 )
+  end if
   call DclDrawTitle( 't', trim(title) )
 
 end subroutine
 
 !-----------------------------------------------
-! ʲ, ñ̥٥ȥ뤬ʤХ
+! 以下, 単位ベクトルが描けないバグ
 
 subroutine axis_vec( p_int, vx, sondeP,  &
   &                  sondeU, sondeV, sondeZ,  &
   &                  view_int, vn, undef,  &
   &                  unit_flag, unity, u_posi, uni_len )
-! skew-T  + vector ޤ롼
-! ȽļΥȥϤ٤ height  temperature Ǹ.
+! skew-T ダイアグラム + vector 図を作成するルーチン
+! 横軸と縦軸のタイトルはすべて height と temperature で固定.
   use Thermo_Const
   use Thermo_Function
   use Statistics
   use Dcl
   implicit none
-  real, intent(in) :: p_int(2)  ! ʵˤξü [Pa]
+  real, intent(in) :: p_int(2)  ! 横軸（気圧）の両端値 [Pa]
                       ! p_int(1)=pmin, p_int(2)=pmax
-  real, intent(in) :: vx   !  vx ɸ.
-  real, intent(in), dimension(:) :: sondeP  ! Ǥε [Pa]
-  real, intent(in), dimension(size(sondeP)) :: sondeU  ! Ǥ [m/s]
-  real, intent(in), dimension(size(sondeP)) :: sondeV  ! Ǥ [m/s]
-  real, intent(in), dimension(size(sondeP)), optional :: sondeZ  ! Ǥι [m]
-  ! sondeP : logP ǽļȤ. ΤȤ, pmin, pmax, sondeP Ϥ٤
-  !               Pa ñ̤ǤȤ뤳.
-  ! sondeZ(optional) : geometric z ǽļȤ.
-  !              ΤȤ, pmin, pmax ϵǤϤʤ, 褷 [m] κǾͤͿ.
-  ! z=-logP δطˤʤ뤬, ǽΤ, ѼԤ
-  ! ˤ, min Ϻ, max Ϻͤ OK.
-  ! ǥեȤǤ, ǽļ.
-  real, intent(in), optional :: view_int(2)  ! viewport ξü.
+  real, intent(in) :: vx   ! 軸線を描く vx 座標.
+  real, intent(in), dimension(:) :: sondeP  ! ゾンデの気圧 [Pa]
+  real, intent(in), dimension(size(sondeP)) :: sondeU  ! ゾンデの東西風 [m/s]
+  real, intent(in), dimension(size(sondeP)) :: sondeV  ! ゾンデの南北風 [m/s]
+  real, intent(in), dimension(size(sondeP)), optional :: sondeZ  ! ゾンデの高度 [m]
+  ! sondeP : logP で縦軸をとる. このとき, pmin, pmax, sondeP はすべて
+  !              気圧を Pa 単位でとること.
+  ! sondeZ(optional) : geometric z で縦軸をとる.
+  !              このとき, pmin, pmax は気圧ではなく, 描画したい高度 [m] の最小最大値を与える.
+  ! z=-logP の関係になるが, それは内部で処理するので, 使用者は
+  ! 気にせず, min は最低値, max は最大値を入れれば OK.
+  ! デフォルトでは, 気圧で縦軸設定.
+  real, intent(in), optional :: view_int(2)  ! viewport の両端.
                                 ! view_int(1)=vmin, view_int(2)=vmax
-                                ! ǥեȤ, (0.2, 0.8) Ǹ.
-  integer, intent(in), optional :: vn  ! ٥ȥδְʻҿ.
-  ! ְ, ɸ˴ؤʻҾ֤.
-  ! ǥեȤ 10 ʻ
-  real, intent(in), optional :: undef  ! ̤, ǥեȤǤꤷʤ.
-  logical, intent(in), optional :: unit_flag  ! ñ̥٥ȥ.
-                                ! default = .false. : ʤ.
-  real, intent(in), optional :: unity  ! unit_flag = .true. λ,
-                                ! ñ̥٥ȥ礭.
-                                ! ꤷʤ, 顼ǽλ.
-                                ! V ɸϤǤ 0.1 ǰ.
-  real, intent(in), optional :: u_posi(2)  ! ñ̥٥ȥθɸ (V ɸ).
+                                ! デフォルトは, (0.2, 0.8) で固定.
+  integer, intent(in), optional :: vn  ! ベクトルの間引き格子数.
+  ! 間引いた場合, 描画座標に関して等格子上に配置する.
+  ! デフォルトは 10 格子
+  real, intent(in), optional :: undef  ! 未定義値, デフォルトでは設定しない.
+  logical, intent(in), optional :: unit_flag  ! 単位ベクトルを描くか.
+                                ! default = .false. : 描かない.
+  real, intent(in), optional :: unity  ! unit_flag = .true. の時,
+                                ! 単位ベクトルの大きさ.
+                                ! 指定しない場合, エラーで終了.
+                                ! V 座標系では 0.1 で一定.
+  real, intent(in), optional :: u_posi(2)  ! 単位ベクトルの原点座標 (V 座標).
                                 ! u_posi=(/vx,vy/)
-                                ! ꤷʤ, ü -0.1 ΤȤ.
-  real, intent(in), optional :: uni_len  ! ñ̥٥ȥĹ (V ɸ).
+                                ! 指定しない場合, 下端の -0.1 のところに描く.
+  real, intent(in), optional :: uni_len  ! 単位ベクトルの長さ (V 座標).
                                 ! default = 0.1
 
-!-- ʾ, 
-  real :: pmin  ! ļʵˤκ [Pa]
-  real :: pmax  ! ļʵˤκǹ [Pa]
-  real :: vmin  ! viewport  min.
-  real :: vmax  ! viewport  max.
+!-- 以上, 引数
+  real :: pmin  ! 縦軸（気圧）の最低値 [Pa]
+  real :: pmax  ! 縦軸（気圧）の最高値 [Pa]
+  real :: vmin  ! viewport の min.
+  real :: vmax  ! viewport の max.
   logical :: u_flag
-!-- ʾ, ֤ѿ
+!-- 以上, 引数の置き換え用変数
   real, dimension(size(sondeP)) :: sondedP, sondelogP
   integer :: i, j, k, nt, vecx
   real :: pdmax, pdmin, dpv
@@ -370,7 +433,7 @@ subroutine axis_vec( p_int, vx, sondeP,  &
      vecx=10
   end if
 
-!-- ʹ, ץ
+!-- 以降, オプション処理
   if(present(view_int))then
      vmin=view_int(1)
      vmax=view_int(2)
@@ -410,12 +473,12 @@ subroutine axis_vec( p_int, vx, sondeP,  &
      ulen=0.1
   end if
 
-!-- ֤ѿ֤
+!-- 引数の置き換え用変数に置き換え
   pmin=p_int(1)
   pmax=p_int(2)
 
   if(present(sondeZ))then
-     ! ٷ׻, z  p ľʤ pt η׻Բǽ (׽)
+     ! 高度計算した場合, z を p に直さないと pt の計算不可能 (要修正)
      pdmax=pmax
      pdmin=pmin
      heiopt_z=.true.
@@ -426,13 +489,13 @@ subroutine axis_vec( p_int, vx, sondeP,  &
 
   do j=1,nt
      if(present(sondeZ))then
-        sondelogP(j)=sondeZ(j)  ! 餯, ͤ undef ˤ DCL ǥ顼Ȥʤ
+        sondelogP(j)=sondeZ(j)  ! おそらく, この値を undef にすると DCL でエラーとなる
      else
-        sondelogP(j)=-log(sondeP(j))  ! 餯, ͤ undef ˤ DCL ǥ顼Ȥʤ
+        sondelogP(j)=-log(sondeP(j))  ! おそらく, この値を undef にすると DCL でエラーとなる
      end if
   end do
 
-!-- ٥ȥδְ
+!-- ベクトルの間引き
   allocate(pv(vecx))
   allocate(interpo(vecx))
   allocate(u(2,vecx))
@@ -444,9 +507,9 @@ subroutine axis_vec( p_int, vx, sondeP,  &
      u(2,i)=undeff
      v(2,i)=undeff
      if(present(sondeZ))then
-        pv(i)=pmin+dpv*(i-1)  ! ٤Ȥ.
+        pv(i)=pmin+dpv*(i-1)  ! 高度として代入.
      else
-        pv(i)=-log(pmax-dpv*(i-1))  ! ٤Ȥ.
+        pv(i)=-log(pmax-dpv*(i-1))  ! 高度として代入.
      end if
      if(sondelogP(nt)>pv(i))then
         call interpo_search_1d( sondelogP, pv(i), interpo(i), int(undeff) )
@@ -454,8 +517,8 @@ subroutine axis_vec( p_int, vx, sondeP,  &
         if(interpo(i)/=int(undeff))then
            if(sondeU(interpo(i))/=undeff.and.sondeU(interpo(i)+1)/=undeff.and.  &
   &           sondeV(interpo(i))/=undeff.and.sondeV(interpo(i)+1)/=undeff)then
-! ϾΥȥȤΤ褦ޤΤ˷׻٤Ǥ뤬,
-! ǡ٤Ȥ, äȤᤤǶƤ褤Ȥ.
+! 本当は上のコメントアウトのように内挿で正確に計算すべきであるが,
+! データ点が細かいことから, もっとも近い点で近似してもよいとする.
               u(2,i)=sondeU(interpo(i))
               v(2,i)=sondeV(interpo(i))
            end if
@@ -463,8 +526,8 @@ subroutine axis_vec( p_int, vx, sondeP,  &
      end if
   end do
 
-!-- DCL 
-!  call SGLSET('LCLIP',.false.)  ! åԥ󥰽
+!-- DCL 前設定
+!  call SGLSET('LCLIP',.false.)  ! クリッピング処理
 
   call DclNewFig
   if(heiopt_z.eqv..true.)then
@@ -484,32 +547,32 @@ subroutine axis_vec( p_int, vx, sondeP,  &
 
   call UGLSET( 'LMSG', .false. )
 
-  call DclDrawVectors( u, v )
-
-!-- ٥ȥ˴ؤ
+!-- ベクトルに関する処理
   if(u_flag.eqv..true.)then
      call DclSetParm( 'VECTOR:LUMSG', .false. )
-     !-- ٥ȥ V ɸѴ
+     !-- ベクトルの V 座標系変換処理
      call DclSetParm( 'VECTOR:LNRMAL', .false. )
      call DclSetParm( 'VECTOR:XFACT1', ulen/unity )
      call DclSetParm( 'VECTOR:YFACT1', ulen/unity )
-     !-- ʲ, ñ̥٥ȥѥ롼Ȥ, ޤʤ.
-     !-- ñ̥٥ȥ.
+     !-- 以下, 単位ベクトル用ルーチンで描こうとしたが, うまく描けない.
+     !-- 単位ベクトルを描くか.
 !     call DclSetParm( 'VECTOR:LUNIT', .true. )
-     !-- ñ̥٥ȥĹ, 踶.
+     !-- 単位ベクトルの長さ, 描画原点指定.
 !     call DclSetParm( 'VECTOR:VXUNIT', ulen )
 !     call DclSetParm( 'VECTOR:VYUNIT', 0.0 )
 !     call DclSetParm( 'VECTOR:VXULOC', uvpx )
 !     call DclSetParm( 'VECTOR:VYULOC', uvpy )
 !     call DclSetUnitVectorTitle( 'X', 'U='//  &
 !  &       trim(adjustl(r2c_convert(unity,'(f6.2)')))//'m s|-1"' )
-     !-- Τ, ad hoc.
+     !-- ので, ad hoc.
      call DclDrawArrowNormalized( uvpx, uvpy, uvpx+ulen, uvpy, index=3 )
      call DclDrawTextNormalized( uvpx+0.5*ulen, uvpy-0.025, 'U='//  &
   &       trim(adjustl(r2c_convert(unity,'(f6.2)')))//'m s\^{-1}',  &
   &       height=0.015, index=3 )
   end if
 
+  call DclDrawVectors( u, v )
+
 end subroutine axis_vec
 
 
