@@ -71,7 +71,7 @@ program draw
      draw_title=trim(title)
   end if
 
-!-- ѿ
+!-- 変数入力
   call HistoryGet( trim(fname), trim(x_axis), x(1:nx) )
   call HistoryGet( trim(fname), trim(y_axis), y(1:ny) )
 
@@ -129,7 +129,7 @@ program draw
      end do
   end if
 
-!-- ƥȥǡ뤫ǧ
+!-- テキストデータがあるか確認
   if(txtname/='')then
      nl=line_number_counter( trim(txtname) )
      allocate(xd(nl,1))
@@ -145,7 +145,7 @@ program draw
      ind=(/8,8/)  ! index define
   end if
 
-!-- ΰη
+!-- 描画領域の決定
   call nearest_search_1d( x, xmin, xdmin )
   call nearest_search_1d( x, xmax, xdmax )
   call nearest_search_1d( y, ymin, ydmin )
@@ -239,7 +239,7 @@ write(*,*) "draw", trim(draw_title)
         xd(i,:)=x(i)
      end do
 
-     ! ΰϰΤ, c  s 礭 cmin, cmax ľ
+     ! 領域描画範囲設定のため, c と s で大きい・小さい方を cmin, cmax に入れ直す
      if(cmin>smin)then
         cmin=smin
      end if
@@ -264,7 +264,7 @@ write(*,*) "draw", trim(draw_title)
   end if
 
   if(fig_type==-2)then  ! y axis line draw
-     allocate(yd(ny,nx))  ! ν֤ 2 ܤοʤΤny, nxؤ.
+     allocate(yd(ny,nx))  ! 引数の順番が 2 要素目が線の数なのでny, nxに入れ替え.
      allocate(dum1(ny,nx))
      allocate(dum2(ny,nx))
      do i=1,ny
@@ -278,7 +278,7 @@ write(*,*) "draw", trim(draw_title)
         end do
      end do
 
-     ! ΰϰΤ, c  s 礭 cmin, cmax ľ
+     ! 領域描画範囲設定のため, c と s で大きい・小さい方を cmin, cmax に入れ直す
      if(cmin>smin)then
         cmin=smin
      end if
