@@ -90,7 +90,7 @@ program poison
 
 !-- gtool history (netcdf dump)
 
-  call HistoryCreate( &                             ! ҥȥ꡼
+  call HistoryCreate( &                             ! ヒストリー作成
     & file='poison.nc', title='poison model', &
     & source='Sample program of gtool_history/gtool5',   &
     & institution='GFD_Dennou Club davis project',       &
@@ -99,20 +99,20 @@ program poison
     & units=(/'m','m'/),                                 &
     & origin=0.0, interval=0.0 )
   
-  call HistoryPut( 'x', x )                            ! ѿ
-  call HistoryPut( 'y', y )                            ! ѿ
+  call HistoryPut( 'x', x )                            ! 次元変数出力
+  call HistoryPut( 'y', y )                            ! 次元変数出力
 
-  call HistoryAddVariable( &                           ! ѿ
+  call HistoryAddVariable( &                           ! 変数定義
     & varname='psi', dims=(/'x','y'/), &
     & longname='psi', units='1', xtype='float')
 
-  call HistoryPut('psi',psi)                         ! ѿ
+  call HistoryPut('psi',psi)                         ! 変数出力
 
-  call HistoryAddVariable( &                           ! ѿ
+  call HistoryAddVariable( &                           ! 変数定義
     & varname='rho', dims=(/'x','y'/), &
     & longname='forcing', units='1', xtype='float')
 
-  call HistoryPut('rho',rho)                         ! ѿ
+  call HistoryPut('rho',rho)                         ! 変数出力
   call HistoryClose
 
   write(*,*) "--------------------------------------------"
