@@ -1,7 +1,7 @@
 program other_2d
-! ʣΥƥȥǡޤץ
-! ꥹȺκݤ 00Z ǻϤޤ, 00Z ǽ褦˺뤳.
-! ­ʤʬ unknown 䤦.
+! 複数のテキストデータから時系列図を作成するプログラム
+! リスト作成の際は 00Z で始まり, 00Z で終わるように作成すること.
+! 足らない部分は unknown で補う.
 
   use dcl
   use Dcl_Automatic
@@ -12,60 +12,60 @@ program other_2d
   implicit none
 
 !-- integer
-  integer :: nt       ! γʻҿ
-  integer :: nz       ! z γʻҿ
-  integer :: nf       ! conv_dat ѥǡ
-  integer :: IWS      ! ǥХ
-  integer :: days     ! 
-  integer :: i_counter    ! 󥿡
-  integer :: i_counter_c  ! 󥿡
-  integer :: snum, cnum  ! 顼ο
-  integer :: skip_num  ! ƬɤФԿ
-  integer, allocatable, dimension(:) :: year_v    ! ǯ
-  integer, allocatable, dimension(:) :: month_v   ! 
-  integer, allocatable, dimension(:) :: day_v     ! 
-  integer, allocatable, dimension(:) :: hour_v    ! 
-  integer, allocatable, dimension(:) :: inter_z ! ѹ
-  integer, allocatable, dimension(:) :: i_flag  ! 
-  integer, allocatable, dimension(:) :: o_flag  ! 
-  integer, allocatable, dimension(:) :: c_flag  ! 
+  integer :: nt       ! 時間方向の格子数
+  integer :: nz       ! z 方向の格子数
+  integer :: nf       ! conv_dat 用データ数
+  integer :: IWS      ! 描画デバイス
+  integer :: days     ! 日数
+  integer :: i_counter    ! 一時カウンター
+  integer :: i_counter_c  ! 一時カウンター
+  integer :: snum, cnum  ! カラーおよび等値線の数
+  integer :: skip_num  ! 先頭読み飛ばし行数
+  integer, allocatable, dimension(:) :: year_v    ! 年
+  integer, allocatable, dimension(:) :: month_v   ! 月
+  integer, allocatable, dimension(:) :: day_v     ! 日
+  integer, allocatable, dimension(:) :: hour_v    ! 時間
+  integer, allocatable, dimension(:) :: inter_z ! 内挿用高度配列
+  integer, allocatable, dimension(:) :: i_flag  ! 一時配列
+  integer, allocatable, dimension(:) :: o_flag  ! 一時配列
+  integer, allocatable, dimension(:) :: c_flag  ! 一時配列
 !-- tmp
   integer :: nttmp, i, j, k, i_undef
   integer :: col_num, idz_val, idc_val, ids_val, idu_val, idv_val
 
 !-- real
-  real :: z_bot       ! βü
-  real :: z_top       ! ξü
-  real :: dz          ! ľֳ [m]
-  real :: dvy         ! vy δֳ
-  real :: smax, smin, cmax, cmin  ! 顼, ξ
-  real, allocatable, dimension(:) :: time  ! 
-  real, allocatable, dimension(:) :: z     ! ٺɸ
-  real, allocatable, dimension(:) :: z_inv ! ٺɸ
-  real, allocatable, dimension(:) :: vx    ! viewport 
-  real, allocatable, dimension(:,:) :: vy  ! viewport 
-  real, allocatable, dimension(:,:) :: val_f        ! ׻
-  real, allocatable, dimension(:,:) :: val_inter    ! ׻ѿ
-  real, allocatable, dimension(:,:) :: tline        ! ׻ѿ
-  real, allocatable, dimension(:,:) :: yline        ! ׻ѿ
-  real, allocatable, dimension(:,:,:) :: val_draw   ! ѿ
+  real :: z_bot       ! 描画の下端
+  real :: z_top       ! 描画の上端
+  real :: dz          ! 鉛直方向の描画間隔 [m]
+  real :: dvy         ! vy の間隔
+  real :: smax, smin, cmax, cmin  ! カラー, 等値線の上限
+  real, allocatable, dimension(:) :: time  ! 時間
+  real, allocatable, dimension(:) :: z     ! 高度座標
+  real, allocatable, dimension(:) :: z_inv ! 高度座標
+  real, allocatable, dimension(:) :: vx    ! viewport 配列
+  real, allocatable, dimension(:,:) :: vy  ! viewport 配列
+  real, allocatable, dimension(:,:) :: val_f        ! 計算用配列
+  real, allocatable, dimension(:,:) :: val_inter    ! 計算用変数配列
+  real, allocatable, dimension(:,:) :: tline        ! 計算用変数配列
+  real, allocatable, dimension(:,:) :: yline        ! 計算用変数配列
+  real, allocatable, dimension(:,:,:) :: val_draw   ! 描画用変数配列
   real :: undef, undef_1d
 !-- tmp
   real, dimension(2) :: s_int, c_int
 
 !-- character
-  character(80) :: flist         ! եꥹ̾
-  character(80) :: dc_val        ! եꥹȤե饰
-  character(80) :: conv_dat      ! ǡ
-  character(80) :: conv_list     ! ǡ
-  character(80) :: title_txt     ! ȥ̾
-  character(10) :: dc_flag       ! ǡե饰
-  character(100) :: z_title      ! ļΥȥ
-  character(20) :: sform, cform  ! եޥå
-  character(80), allocatable, dimension(:,:) :: fname  ! ե̾
-  character(20), allocatable, dimension(:,:) :: val_w  ! ƥȥǡ
-  character(100) :: skip_char    ! Ƭإå̻
-                                 ! ɤФԿưեޥåȤκݻ.
+  character(80) :: flist         ! ファイルリスト名
+  character(80) :: dc_val        ! ファイルリストの描画フラグ
+  character(80) :: conv_dat      ! 時系列データ
+  character(80) :: conv_list     ! 時系列データ
+  character(80) :: title_txt     ! タイトル名
+  character(10) :: dc_flag       ! カラムデータフラグ
+  character(100) :: z_title      ! 縦軸のタイトル
+  character(20) :: sform, cform  ! フォーマット
+  character(80), allocatable, dimension(:,:) :: fname  ! ファイル名
+  character(20), allocatable, dimension(:,:) :: val_w  ! テキストデータ
+  character(100) :: skip_char    ! 先頭ヘッダー識別子
+                                 ! 読み飛ばし行数が変動するフォーマットの際使用.
   character(70) :: sysfont
 !-- tmp
   character(80), allocatable, dimension(:) :: dummy_read
@@ -73,8 +73,8 @@ program other_2d
   character(1) :: skip_flag
 
 !-- logical
-  logical :: inv_flag  ! ž뤫Υե饰.
-                       ! ǼƤٺɸžȤ .true.
+  logical :: inv_flag  ! 軸を逆転させるかのフラグ.
+                       ! 格納されている高度座標を逆転させるときは .true.
   logical :: fflag, cont_flag, shade_flag, u_flag, v_flag
 
 !-- type
@@ -284,7 +284,7 @@ program other_2d
   end do
 
 !-- DCL part
-!-- ޤ, -
+!-- まず, 高度-時系列断面
   call color_setting( snum, s_int, col_min=15, col_max=85,  &
   &                   min_tab=10999, max_tab=99999 )
 
@@ -363,7 +363,7 @@ program other_2d
      end if
   end if
 
-!-- ʹ, ήѥ᡼ѿλǡ񤭽Ф
+!-- 以降, 対流パラメータ変数の時系列データ書き出し
 
   deallocate(fname)
   deallocate(year_v)
@@ -430,7 +430,7 @@ program other_2d
 
      if(i_counter>0)then
 
-     !-- vx  i_counter ʬ.
+     !-- vx を i_counter で分ける.
         allocate(vx(2))
         allocate(vy(i_counter,2))
         vx=(/0.2, 0.95/)
