@@ -1,7 +1,7 @@
 program sound_2d
-! ʣΥǥǡޤץ
-! ꥹȺκݤ 00Z ǻϤޤ, 00Z ǽ褦˺뤳.
-! ­ʤʬ unknown 䤦.
+! 複数のゾンデデータから時系列図を作成するプログラム
+! リスト作成の際は 00Z で始まり, 00Z で終わるように作成すること.
+! 足らない部分は unknown で補う.
 
   use file_operate
   use basis
@@ -13,29 +13,27 @@ program sound_2d
 
   implicit none
 
+  character(3), dimension(12), parameter :: cmonth=(/'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'/)
+  integer, parameter :: labelnmax=100    ! maximum element number for label
+
 !-- integer
-  integer :: nt       ! γʻҿ
-  integer :: nz       ! z γʻҿ
-  integer :: nf       ! conv_dat ѥǡ
+  integer :: nt       ! 時間方向の格子数
+  integer :: nz       ! z 方向の格子数
+  integer :: nf       ! conv_dat 用データ数
   integer :: ntnum, nznum  ! number of vector for nt and nz
-  integer :: iz_ref   ! dz = 0 ΤȤ, flist  iz_ref ܤι٥ǡ.
-  integer :: IWS      ! ǥХ
-  integer :: days     ! 
-  integer :: i_counter    ! 󥿡
-  integer :: i_counter_c  ! 󥿡
-  integer :: snum, cnum  ! 顼ο
-  integer :: cont_flag, shade_flag  ! 顼, ѥե饰ѿ
-  integer :: cmap  ! 顼ޥå
+  integer :: iz_ref   ! dz = 0 のとき, flist の iz_ref 行目の高度データで描く.
+  integer :: IWS      ! 描画デバイス
+  integer :: i_counter    ! 一時カウンター
+  integer :: i_counter_c  ! 一時カウンター
+  integer :: snum, cnum  ! カラーおよび等値線の数
+  integer :: cont_flag, shade_flag  ! カラー, 等値線用フラグ変数
+  integer :: cmap  ! カラーマップ
   integer :: izmin, izmax
-  integer, allocatable, dimension(:) :: year_v    ! ǯ
-  integer, allocatable, dimension(:) :: month_v   ! 
-  integer, allocatable, dimension(:) :: day_v     ! 
-  integer, allocatable, dimension(:) :: hour_v    ! 
-  integer, allocatable, dimension(:) :: inter_z ! ѹ
-  integer, allocatable, dimension(:) :: i_flag  ! 
-  integer, allocatable, dimension(:) :: o_flag  ! 
-  integer, allocatable, dimension(:) :: c_flag  ! 
-  integer :: fixsn(100)  ! 顼ʪ̤б륫顼ޥå
+  integer, allocatable, dimension(:) :: inter_z ! 内挿用高度配列
+  integer, allocatable, dimension(:) :: i_flag  ! 一時配列
+  integer, allocatable, dimension(:) :: o_flag  ! 一時配列
+  integer, allocatable, dimension(:) :: c_flag  ! 一時配列
+  integer :: fixsn(100)  ! カラー指定時の物理量に対応するカラーマップ値
 
 !-- tmp
   integer :: nttmp, i, j, k, i_undef, i_tmp
@@ -45,61 +43,67 @@ program sound_2d
   real, parameter :: vxint(2)=(/0.1,0.9/)
   real, parameter :: vyint(2)=(/0.15,0.9/)
   real, parameter :: unitfact(2)=(/0.05, 0.05/)  ! unit vector for V coord.
+  integer, dimension(2) :: labelnum, ticknum
 
 !-- real
-  real :: z_bot       ! βü
-  real :: z_top       ! ξü
-  real :: dz          ! ľֳ [m]
-  real :: dvy         ! vy δֳ
-  real :: smax, smin, cmax, cmin  ! 顼, ξ
-  real, allocatable, dimension(:) :: time  ! 
-  real, allocatable, dimension(:) :: z     ! ٺɸ
-  real, allocatable, dimension(:) :: vx     ! viewport 
-  real, allocatable, dimension(:,:) :: vy     ! viewport 
-  real, allocatable, dimension(:,:) :: val_f        ! ׻
-  real, allocatable, dimension(:,:) :: val_inter    ! ׻ѿ
-  real, allocatable, dimension(:,:) :: tline        ! ׻ѿ
-  real, allocatable, dimension(:,:) :: yline        ! ׻ѿ
-  real, allocatable, dimension(:,:,:) :: val_draw   ! ѿ
+  real :: z_bot       ! 描画の下端
+  real :: z_top       ! 描画の上端
+  real :: dz          ! 鉛直方向の描画間隔 [m]
+  real :: dvy         ! vy の間隔
+  real :: smax, smin, cmax, cmin  ! カラー, 等値線の上限
+  real, allocatable, dimension(:) :: time  ! 時間
+  real, allocatable, dimension(:) :: z     ! 高度座標
+  real, allocatable, dimension(:) :: vx     ! viewport 配列
+  real, allocatable, dimension(:,:) :: vy     ! viewport 配列
+  real, allocatable, dimension(:,:) :: val_f        ! 計算用配列
+  real, allocatable, dimension(:,:) :: val_inter    ! 計算用変数配列
+  real, allocatable, dimension(:,:) :: tline        ! 計算用変数配列
+  real, allocatable, dimension(:,:) :: yline        ! 計算用変数配列
+  real, allocatable, dimension(:,:,:) :: val_draw   ! 描画用変数配列
   real :: undef
-  real :: conv_undef
+  real :: conv_undef, tfact
   real :: ymin, ymax, vx_new(2), vy_new(2)
   real :: unitfactv(2)
-  real :: fixs(100)  ! 顼ʪ
-  !  fixs(snum+1), fixsn(snum+2)  fixsn(1), fixsn(snum+2) ǾΥ顼
+  real :: fixs(100)  ! カラー指定時の物理量
+  real, dimension(2) :: mxitv, myitv
+  ! 指定時は fixs(snum+1), fixsn(snum+2) で fixsn(1), fixsn(snum+2) が最大最小のカラー
+  real, dimension(labelnmax) :: axlbl, aylbl, axtck, aytck
 
 !-- tmp
   real, dimension(2) :: pt_tmp, ept_tmp, sept_tmp, rh_tmp, s_int, c_int
 
 !-- character
-  character(1000) :: flist         ! եꥹ̾
-  character(1000) :: conv_dat      ! sound_1d ǽϤήѥ᡼ǡ
-  character(1000) :: title_txt     ! ȥ̾
-  character(10) :: cont_val      ! ѿ̾
-  character(10) :: shade_val     ! 顼ѿ̾
-  character(10) :: conv_list     ! ǡե饰
-  character(1000), allocatable, dimension(:,:) :: fname  ! ե̾
-  character(1000), allocatable, dimension(:,:) :: val_w  ! ƥȥǡ
+  character(1000) :: flist         ! ファイルリスト名
+  character(1000) :: conv_dat      ! sound_1d で出力した対流パラメータ時系列データ
+  character(1000) :: title_txt     ! タイトル名
+  character(10) :: cont_val      ! 等値線描画用変数名
+  character(10) :: shade_val     ! カラー描画用変数名
+  character(10) :: conv_list     ! カラムデータフラグ
+  character(1000), allocatable, dimension(:,:) :: fname  ! ファイル名
+  character(1000), allocatable, dimension(:,:) :: val_w  ! テキストデータ
   character(70) :: sysfont
   character(10) :: unitval     ! value of unit vector [m/s]
   character(20) :: unititle   ! unit vector title
+  character(20), dimension(labelnmax) :: cxlbl, cylbl
+  character(1) :: tonef
 !-- tmp
   character(1000) :: tmp_c
 
 !-- logical
-  logical :: vec_val       ! ѿ̾
+  logical :: vec_val       ! 矢印描画用変数名
   logical :: fflag, fixs_flag
 
 !-- type
-  type(dtime) :: start_day, end_day
-  type(dcl_date) :: stime
+  type(dtime) :: inidate, curdate
 
 !-- namelist reading
   namelist /input /flist, conv_dat, conv_list, conv_undef, dz, z_bot,  &
   &                z_top, iz_ref, IWS, title_txt, cmap,  &
   &                cmin, cmax, smin, smax, cont_val, shade_val,  &
   &                vec_val, cnum, snum, undef, sysfont, ntnum, nznum,  &
-  &                unitval, fixs_flag, fixs, fixsn
+  &                unitval, fixs_flag, fixs, fixsn,  &
+  &                mxitv, myitv, tonef, labelnum, axlbl, cxlbl, aylbl, cylbl,  &
+  &                ticknum, axtck, aytck, tfact
   read(5,nml=input)
 
   fflag=.false.
@@ -126,10 +130,6 @@ program sound_2d
   allocate(inter_z(nz))
   allocate(val_inter(col_num+4,nz))
   allocate(val_draw(col_num+4,nt,nz))
-  allocate(year_v(nt))
-  allocate(month_v(nt))
-  allocate(day_v(nt))
-  allocate(hour_v(nt))
 
 !-- DCL set
   if(len_trim(adjustl(sysfont))/=0)then
@@ -146,30 +146,28 @@ program sound_2d
   CALL GLRSET( 'RMISS', undef )
   CALL GLLSET( 'LMISS', .TRUE. )
 
-  do i=1,nt
+!-- reading data
+  tmp_c=trim(fname(2,1))
+  inidate%year_d=c2i_convert( tmp_c(1:4) )
+  inidate%month_d=c2i_convert( tmp_c(5:6) )
+  inidate%day_d=c2i_convert( tmp_c(7:8) )
+  inidate%hour_d=c2i_convert( tmp_c(9:10) )
+  inidate%min_d=c2i_convert( tmp_c(11:12) )
+  inidate%sec_d=c2i_convert( tmp_c(13:14) )
+  time(1)=0.0
+
+  do i=2,nt
      tmp_c=trim(fname(2,i))
-     year_v(i)=c2i_convert( trim(tmp_c(1:4)) )
-     month_v(i)=c2i_convert( trim(tmp_c(5:6)) )
-     day_v(i)=c2i_convert( trim(tmp_c(7:8)) )
-     hour_v(i)=c2i_convert( trim(tmp_c(9:10)) )
+     curdate%year_d=c2i_convert( tmp_c(1:4) )
+     curdate%month_d=c2i_convert( tmp_c(5:6) )
+     curdate%day_d=c2i_convert( tmp_c(7:8) )
+     curdate%hour_d=c2i_convert( tmp_c(9:10) )
+     curdate%min_d=c2i_convert( tmp_c(11:12) )
+     curdate%sec_d=c2i_convert( tmp_c(13:14) )
+     time(i)=counter_sec( inidate, curdate )
   end do
 
-  start_day%year_d=year_v(1)
-  start_day%month_d=month_v(1)
-  start_day%day_d=day_v(1)
-  start_day%hour_d=hour_v(1)
-  start_day%min_d=0
-  start_day%sec_d=0
-  end_day%year_d=year_v(nt)
-  end_day%month_d=month_v(nt)
-  end_day%day_d=day_v(nt)
-  end_day%hour_d=hour_v(nt)
-  end_day%min_d=0
-  end_day%sec_d=0
-  days=counter_day( start_day, end_day )-1
-  stime%year=year_v(1)
-  stime%month=month_v(1)
-  stime%day=day_v(1)
+  time=time*tfact
 
   if(dz==0.0)then
      write(*,*) "*** MESSAGE (main) *** : z is specified by "  &
@@ -202,14 +200,6 @@ program sound_2d
      ntnum=nt
   end if
 
-  do i=1,nt
-     end_day%year_d=year_v(i)
-     end_day%month_d=month_v(i)
-     end_day%day_d=day_v(i)
-     time(i)=real(counter_day( start_day, end_day ))  &
-  &         +real(hour_v(i)-hour_v(1))/24.0-1.0
-  end do
-
 !-- time loop
 !-- 1. reading values from text file
 !-- 2. interpolating to grid point
@@ -241,13 +231,12 @@ program sound_2d
               if(inter_z(k)/=int(undef).and.inter_z(k)/=nttmp)then
                  if(val_f(j,inter_z(k))==undef.or.  &
   &                 val_f(j,inter_z(k)+1)==undef)then
-                    val_inter(:,k)=undef
-                    exit
+                    val_inter(j,k)=undef
+                 else
+                    call interpolation_1d( val_f(1,inter_z(k):inter_z(k)+1),  &
+  &                                        val_f(j,inter_z(k):inter_z(k)+1),  &
+  &                                        z(k), val_inter(j,k) )
                  end if
-
-                 call interpolation_1d( val_f(1,inter_z(k):inter_z(k)+1),  &
-  &                                     val_f(j,inter_z(k):inter_z(k)+1),  &
-  &                                     z(k), val_inter(j,k) )
               else
                  val_inter(j,k)=undef
               end if
@@ -302,7 +291,7 @@ program sound_2d
 
      do j=1,col_num+4
         do k=1,nz
-           if(j==4)then  ! ˤĤƤν.
+           if(j==4)then  ! 水蒸気混合比についての処理.
               if(val_inter(j,k)/=undef)then
                  val_draw(j,i,k)=val_inter(j,k)*1.0e3
               else
@@ -317,7 +306,7 @@ program sound_2d
   end do
 
 !-- draw value separate
-!--  val_inter ȤƤ.(ޤ̤)
+!-- 全て val_inter に落としておく.(上まだ未完全)
 
   select case (cont_val)
   case ('temp')
@@ -358,7 +347,7 @@ program sound_2d
   end select
 
 !-- DCL part
-!-- ޤ, -
+!-- まず, 高度-時系列断面
   if(fixs_flag.eqv..true.)then
 call sgscmn( cmap )
      call color_setting( snum, s_int,  &
@@ -380,31 +369,39 @@ call sgscmn( cmap )
   end if
 
   if(vec_val.eqv..false.)then
-     call Dcl_2D_Cont_Shade_Calendar( trim(title_txt),  &
+     call Dcl_2D_Cont_Shade( trim(title_txt),  &
   &       time, z(izmin:izmax),  &
   &       val_draw(cont_flag,:,izmin:izmax),  &
   &       val_draw(shade_flag,:,izmin:izmax),  &
   &       c_int, s_int,  &
-  &       (/'            ', 'altitude (m)'/), stime, days, (/'(f6.1)', '(f6.1)'/),  &
+  &       (/'            ', 'altitude (m)'/), (/'(f6.1)', '(f6.1)'/),  &
   &       viewx_int=vxint, viewy_int=vyint,  &
-  &       c_num=(/cnum, snum/), no_tone=.true. )
+  &       c_num=(/cnum, snum/), no_tone=.true.,  &
+  &       mxitv=mxitv, myitv=myitv, tonbf=tonef(1:1),  &
+  &       axlbl=axlbl(1:labelnum(1)), cxlbl=cxlbl(1:labelnum(1)),  &
+  &       aylbl=aylbl(1:labelnum(2)), cylbl=cylbl(1:labelnum(2)),  &
+  &       axtck=axtck(1:ticknum(1)), aytck=aytck(1:ticknum(2)) )
   else
-     call Dcl_2D_Cont_Shade_vec_Calendar( trim(title_txt),  &
+     call Dcl_2D_Cont_Shade_vec( trim(title_txt),  &
   &       time, z(izmin:izmax),  &
   &       val_draw(cont_flag,:,izmin:izmax),  &
   &       val_draw(shade_flag,:,izmin:izmax),  &
   &       val_draw(5,:,izmin:izmax), val_draw(6,:,izmin:izmax),  &
   &       (/ntnum,nznum/), c_int, s_int,  &
-  &       (/'            ', 'altitude (m)'/), stime, days,  &
+  &       (/'            ', 'altitude (m)'/),  &
   &       (/'(f6.1)', '(f6.1)'/),  &
   &       viewx_int=vxint, viewy_int=vyint,  &
   &       c_num=(/cnum, snum/), no_tone=.true.,  &
+  &       mxitv=mxitv, myitv=myitv, tonbf=tonef(1:1),  &
+  &       axlbl=axlbl(1:labelnum(1)), cxlbl=cxlbl(1:labelnum(1)),  &
+  &       aylbl=aylbl(1:labelnum(2)), cylbl=cylbl(1:labelnum(2)),  &
+  &       axtck=axtck(1:ticknum(1)), aytck=aytck(1:ticknum(2)),  &
   &       unitv=.true., vfact=unitfactv, unit_fact=unitfact,  &
   &       unit_fact_sign=.false.,  &
   &       unit_title=(/trim(adjustl(unititle)), '                    '/) )
   end if
 
-  call DclSetParm( "GRAPH:LCLIP", .true. )
+  call DclSetParm( "GRAPH:LCLIP", .false. )
   call DclDrawMarker( (/0.0/), (/0.0/) )
   CALL SGQVPT( vx_new(1), vx_new(2), vy_new(1), vy_new(2) )
   call DclSetParm( "GRAPH:LCLIP", .false. )
@@ -424,13 +421,9 @@ call sgscmn( cmap )
   end if
   call DclSetParm( "GRAPH:LCLIP", .true. )
 
-!-- ʹ, ήѥ᡼ѿλǡ񤭽Ф
+!-- 以降, 対流パラメータ変数の時系列データ書き出し
 
   deallocate(fname)
-  deallocate(year_v)
-  deallocate(month_v)
-  deallocate(day_v)
-  deallocate(hour_v)
   deallocate(time)
 
   if(trim(conv_dat(1:1))/='')then
@@ -438,10 +431,6 @@ call sgscmn( cmap )
      nt=line_number_counter( trim(conv_dat) )
 
      allocate(fname(nf,nt))
-     allocate(year_v(nt-2))
-     allocate(month_v(nt-2))
-     allocate(day_v(nt-2))
-     allocate(hour_v(nt-2))
      allocate(i_flag(3))
      allocate(o_flag(nf))
      allocate(c_flag(nf))
@@ -470,35 +459,31 @@ call sgscmn( cmap )
         end select
      end do
 
-     do i=1,nt-2
+     tmp_c=trim( adjustl( fname(i_flag(1),3) ) )
+     inidate%year_d=c2i_convert( tmp_c(1:4) )
+     inidate%month_d=c2i_convert( tmp_c(5:6) )
+     inidate%day_d=c2i_convert( tmp_c(7:8) )
+     inidate%hour_d=c2i_convert( tmp_c(9:10) )
+     inidate%min_d=c2i_convert( tmp_c(11:12) )
+     inidate%sec_d=c2i_convert( tmp_c(13:14) )
+     time(1)=0.0
+
+     do i=2,nt
         tmp_c=trim( adjustl( fname(i_flag(1),i+2) ) )
-        year_v(i)=c2i_convert( trim(tmp_c(1:4)) )
-        month_v(i)=c2i_convert( trim(tmp_c(5:6)) )
-        day_v(i)=c2i_convert( trim(tmp_c(7:8)) )
-        hour_v(i)=c2i_convert( trim(tmp_c(9:10)) )
+        curdate%year_d=c2i_convert( tmp_c(1:4) )
+        curdate%month_d=c2i_convert( tmp_c(5:6) )
+        curdate%day_d=c2i_convert( tmp_c(7:8) )
+        curdate%hour_d=c2i_convert( tmp_c(9:10) )
+        curdate%min_d=c2i_convert( tmp_c(11:12) )
+        curdate%sec_d=c2i_convert( tmp_c(13:14) )
+        time(i)=counter_sec( inidate, curdate )
      end do
 
-     start_day%year_d=year_v(1)
-     start_day%month_d=month_v(1)
-     start_day%day_d=day_v(1)
-     end_day%year_d=year_v(nt-2)
-     end_day%month_d=month_v(nt-2)
-     end_day%day_d=day_v(nt-2)
-     days=counter_day( start_day, end_day )-1
-     stime%year=year_v(1)
-     stime%month=month_v(1)
-     stime%day=day_v(1)
-
-     do i=1,nt-2
-        end_day%year_d=year_v(i)
-        end_day%month_d=month_v(i)
-        end_day%day_d=day_v(i)
-        time(i)=real(counter_day( start_day, end_day ))+real(hour_v(i))/24.0-1.0
-     end do
+     time=time*tfact
 
      if(i_counter>0)then
 
-     !-- vx  i_counter ʬ.
+     !-- vx を i_counter で分ける.
         allocate(vx(2))
         allocate(vy(i_counter,2))
         vx=(/0.2, 0.95/)
@@ -539,12 +524,16 @@ call sgscmn( cmap )
            call min_val_1d( yline(i_undef:nt-2,j), i_tmp, ymin, undef )
            call max_val_1d( yline(i_undef:nt-2,j), i_tmp, ymax, undef )
 
-           call Dcl_PL_Calendar( 'l', '',   &
+           call Dcl_PL( 'l', '',   &
   &             tline(i_undef:nt-2,j:j), yline(i_undef:nt-2,j:j),  &
   &             tline(i_undef:nt-2,j:j), yline(i_undef:nt-2,j:j),  &
   &             (/trim(tmp_c), trim(tmp_c)/),  &
-  &             stime, days, viewx_int=vx, viewy_int=vy(j,:),  &
+  &             viewx_int=vx, viewy_int=vy(j,:),  &
   &             x_int=(/tline(1,1),tline(nt-2,1)/), y_int=(/ymin,ymax/),  &
+  &             mxitv=mxitv, myitv=myitv,  &
+  &             axlbl=axlbl(1:labelnum(1)), cxlbl=cxlbl(1:labelnum(1)),  &
+  &             aylbl=aylbl(1:labelnum(2)), cylbl=cylbl(1:labelnum(2)),  &
+  &             axtck=axtck(1:ticknum(1)), aytck=aytck(1:ticknum(2)),  &
   &             no_frame=fflag )
         end do
 
@@ -579,11 +568,15 @@ call sgscmn( cmap )
         call max_val_2d( yline(i_undef:nt-2,1:c_flag(j)),  &
   &                      i_tmp, i_tmp, ymax, undef )
 
-        call Dcl_PL_Calendar( 'l', '',  &
+        call Dcl_PL( 'l', '',  &
   &          tline(i_undef:nt-2,1:c_flag(j)), yline(i_undef:nt-2,1:c_flag(j)),  &
   &          tline(i_undef:nt-2,1:c_flag(j)), yline(i_undef:nt-2,1:c_flag(j)),  &
-  &          (/'', trim(tmp_c)/), stime, days,  &
-  &          x_int=(/tline(1,1),tline(nt-2,1)/), y_int=(/ymin,ymax/) )
+  &          (/'', trim(tmp_c)/),  &
+  &          x_int=(/tline(1,1),tline(nt-2,1)/), y_int=(/ymin,ymax/),  &
+  &          mxitv=mxitv, myitv=myitv,  &
+  &          axlbl=axlbl(1:labelnum(1)), cxlbl=cxlbl(1:labelnum(1)),  &
+  &          aylbl=aylbl(1:labelnum(2)), cylbl=cylbl(1:labelnum(2)),  &
+  &          axtck=axtck(1:ticknum(1)), aytck=aytck(1:ticknum(2)) )
 
      end if
 
