@@ -1,6 +1,6 @@
 program sound_conv
-! ǤդΥǥ󥰥ǡᥤץबɤ߹ߤ䤹Ѵ.
-! ٤뤤ϰϤ̤ä,  array ѴΥեˤϽϤʤ.
+! 任意のサウンディングデータをメインプログラムが読み込みやすい形に変換する.
+! 高度あるいは圧力に未定義が入った場合, その array は変換後のファイルには出力しない.
   use file_operate
   use Basis
   use Math_Const
@@ -10,31 +10,32 @@ program sound_conv
   implicit none
 
   real, allocatable, dimension(:,:) :: val
-  character(30), allocatable, dimension(:,:) :: cval
+  character(1000), allocatable, dimension(:,:) :: cval
   integer :: id, i, j, k, nx, nz, i_undef, skip_num, rh_flag, nf, neg_i
-  character(100) :: sign_flag, tmpc
-  character(200) :: output_name, undef, fname
-  character(200), allocatable, dimension(:) :: iname, oname
+  character(1000) :: sign_flag, tmpc
+  character(1000) :: output_name, undef, fname
+  character(1000), allocatable, dimension(:) :: iname, oname
   character(10) :: unity(6)  ! unit convert flags
   character(20) :: foma, fomb
   character(1) :: hydro_flag
-  real :: conv_undef, hydro_ref
+  real :: conv_undef, hydro_ref, tmp_height
+  real, dimension(6) :: sfact
   real :: limit_height, factor, ew_tmp, ww_tmp, snd_height, conv_height, dz_conv
   real, allocatable, dimension(:) :: height, pres, temp, vapor, tmp, ew, ww
-  logical :: limit_flag, conv_inter, continu_flag, write_flag, rev_flag
-
-  i_undef=len_trim(undef)
-  foma='(6a15)'
-  fomb='(6E15.6)'
+  logical :: limit_flag, conv_inter, write_flag, rev_flag
 
 !-- namelist file read
 
 !  call read_namelist()
-  namelist /input /fname, undef, sign_flag, skip_num, unity, limit_height,  &
+  namelist /input /fname, undef, sign_flag, skip_num, unity, sfact, limit_height,  &
   &                snd_height, output_name, dz_conv, conv_inter, conv_undef,  &
-  &                continu_flag, hydro_ref, rev_flag
+  &                hydro_ref, rev_flag
   read(5,nml=input)
 
+  i_undef=len_trim(undef)
+  foma='(6a15)'
+  fomb='(6E15.6)'
+
 !-- list file read
 
   nf=line_number_counter( trim(fname) )
@@ -103,6 +104,10 @@ program sound_conv
      allocate(ww(nz))
      allocate(tmp(nz))
 
+     height=conv_undef
+     temp=conv_undef
+     pres=conv_undef
+     vapor=conv_undef
      ew=conv_undef
      ww=conv_undef
 
@@ -154,9 +159,9 @@ program sound_conv
         select case (sign_flag(i:i))
         case('1')
            if(unity(1)=='m')then
-              factor=1.0
+              factor=1.0*sfact(1)
            else
-              factor=1000.0
+              factor=1000.0*sfact(1)
            end if
            do j=neg_i,nz
               if(val(i,j)/=conv_undef)then
@@ -180,16 +185,16 @@ program sound_conv
            end if
            do j=neg_i,nz
               if(val(i,j)/=conv_undef)then
-                 temp(j)=val(i,j)+factor
+                 temp(j)=val(i,j)*sfact(2)+factor
               else
                  temp(j)=conv_undef
               end if
            end do
         case('3')
            if(unity(3)=='Pa')then
-              factor=1.0
+              factor=1.0*sfact(3)
            else
-              factor=100.0
+              factor=100.0*sfact(3)
            end if
            do j=neg_i,nz
               if(val(i,j)/=conv_undef)then
@@ -211,7 +216,7 @@ program sound_conv
            end if
            do j=neg_i,nz
               if(val(i,j)/=conv_undef.or.val(i,j)>=0.0)then
-                 vapor(j)=val(i,j)*factor
+                 vapor(j)=val(i,j)*sfact(4)*factor
               else
                  vapor(j)=conv_undef
               end if
@@ -219,7 +224,7 @@ program sound_conv
         case('5')
            do j=neg_i,nz
               if(val(i,j)/=conv_undef)then
-                 ew(j)=val(i,j)
+                 ew(j)=val(i,j)*sfact(5)
               else
                  ew(j)=conv_undef
               end if
@@ -227,7 +232,7 @@ program sound_conv
         case('6')
            do j=neg_i,nz
               if(val(i,j)/=conv_undef)then
-                 ww(j)=val(i,j)
+                 ww(j)=val(i,j)*sfact(6)
               else
                  ww(j)=conv_undef
               end if
@@ -254,7 +259,8 @@ program sound_conv
 !        pres(neg_i)=exner_func_dry( hydro_ref )
         pres(neg_i)=hydro_ref
         do j=neg_i+1,nz
-           if(height(j)/=conv_undef.and.height(j-1)/=conv_undef)then  ! Temp.
+           if(height(j)/=conv_undef.and.height(j-1)/=conv_undef.and.  &
+  &           temp(j)/=conv_undef.and.temp(j-1)/=conv_undef)then  ! Temp.
               if(unity(2)=='K'.or.unity(2)=='degC')then
                  pres(j)=pres(j-1)*exp(-0.5*(g/Rd)*((height(j)-height(j-1))  &
   &                                    *(1.0/temp(j-1)+1.0/temp(j))))
@@ -270,7 +276,8 @@ program sound_conv
      case ('z')
         height(neg_i)=hydro_ref
         do j=neg_i+1,nz
-           if(pres(j)/=conv_undef.and.pres(j-1)/=conv_undef)then
+           if(pres(j)/=conv_undef.and.pres(j-1)/=conv_undef.and.  &
+  &           temp(j)/=conv_undef.and.temp(j-1)/=conv_undef)then  ! Temp.
               if(unity(2)=='K'.or.unity(2)=='degC')then
                  height(j)=height(j-1)-0.5*(Rd/g)*(log(pres(j)/pres(j-1)))  &
   &                                    *(temp(j)+temp(j-1))
@@ -304,6 +311,24 @@ program sound_conv
         end do
      end if
 
+     if(unity(4)=='degC')then  ! TD(degC)
+        do j=neg_i,nz
+           if(vapor(j)/=conv_undef)then
+              vapor(j)=RHTP_2_qv( TTd_2_RH_Bolton( temp(j), vapor(j)+273.15 ),  &
+  &                               temp(j), pres(j) )
+           end if
+        end do
+     end if
+
+     if(unity(4)=='K')then  ! TD(K)
+        do j=neg_i,nz
+           if(vapor(j)/=conv_undef)then
+              vapor(j)=RHTP_2_qv( TTd_2_RH_Bolton( temp(j), vapor(j) ),  &
+  &                               temp(j), pres(j) )
+           end if
+        end do
+     end if
+
 !-- convert check wind radian
 
      if(unity(5)=='rad')then
@@ -355,10 +380,20 @@ program sound_conv
 
      conv_height=limit_height
      write_flag=.true.
+     tmp_height=limit_height
+
+     do j=neg_i,nz
+        if((height(j)>=limit_height).and.(height(j)/=conv_undef))then
+           !if(height(j)>=0.0.and.pres(j)>0.0)then
+           if(height(j)>=0.0)then
+              if(height(j)<=tmp_height)then
+                 write_flag=.false.
+                 exit
+              else
+                 write_flag=.true.
+              end if
+              tmp_height=height(j)
 
-     do j=neg_i,nz-1
-        if(height(j)>=limit_height)then
-           if(height(j)>=0.0.and.pres(j)>0.0)then
               if(write_flag.eqv..true.)then
                  if(conv_inter.eqv..false.)then
                     write(11+id,trim(fomb)) height(j), pres(j), temp(j),  &
@@ -371,17 +406,6 @@ program sound_conv
                     end if
                  end if
               end if
-
-              if(height(j+1)<=height(j))then
-                 if(continu_flag.eqv..false.)then
-                    write_flag=.true.
-                    exit
-                 else
-                    write_flag=.false.
-                 end if
-              else
-                 write_flag=.true.
-              end if
            end if
         end if
 !        if(j==nz-1)then
