@@ -1,4 +1,4 @@
-program thermo  ! thermo طδؿǧ
+program thermo  ! thermo 関係の関数確認用
   use Thermo_Function
   implicit none
   integer, parameter :: dl=2
