@@ -3,7 +3,7 @@
 !---------------------------------------------------------------
 
 module Assimilation
-! ǡƱɬפȤʤ롼
+! データ同化に必要となるルーチン集
   use statistics
   use max_min
 
@@ -11,29 +11,29 @@ contains
 
 subroutine successive_modif_1d( x, fg, obs_posi, obs, method, inter_val,  &
   &                             rad, hx, hobs, lambda )!, undef )
-! 1 ǡˤĤ, ༡ˡˤޤԤ.
-! , ͤ¬ؤޤޤԤΤȤ.
-! ͤ򥼥Ȥ, ༡ޤԤ.
-! Ĥޤ, ¬ͤΤߤꤷޤԤ.
+! 1 次元データについて, 逐次修正法による内挿を行う.
+! ここで, 第一推定値から観測点への内挿は線形内挿を行うものとする.
+! 第一推定値をゼロとすれば, 純粋な逐次内挿が行われる.
+! つまり, 観測値のみから推定した内挿が行える.
   implicit none
-  real, intent(in) :: x(:)  ! Ǥκɸ[ľɸ]
-  real, intent(in) :: fg(size(x))  ! Ǥ
-  real, intent(in) :: obs_posi(:)  ! ¬κɸ[x ϤǤ]
-  real, intent(in) :: obs(size(obs_posi))  ! ¬Ǥδ¬
-  character(1), intent(in) :: method  ! ƶη
-                              ! 'B' : Barnes (1964) ˤ륬
-                              ! 'C' : Cressman (1959) ˤͭµ
-  real, intent(inout) :: inter_val(size(x))  ! ޤ줿
-  real, intent(in), optional :: rad  ! ƶȾ[x ϤǤ]
-                                     ! ǥեȤϳƳʻκǶδ¬
-                                     ! ׻, κǱΥ.
-  real, intent(in), optional :: hx(size(x))  ! x Ϥˤ륹.
-                                ! ǥեȤϥǥȺɸϤȤƷ׻.
-  real, intent(in), optional :: hobs(size(obs_posi))  ! ¬줿 x Ϥˤ륹.
-                                ! ǥեȤϥǥȺɸϤȤƷ׻.
-  real, intent(in), optional :: lambda  ! ¬ɸк / طʸɸк
-                                       ! ǥեȤǤϥ.
-!  real, intent(in), optional :: undef  ! ¬η»[ͤˤϷ»ʤ]
+  real, intent(in) :: x(:)  ! 内挿点での座標値[直交座標系]
+  real, intent(in) :: fg(size(x))  ! 内挿点での第一推定値
+  real, intent(in) :: obs_posi(:)  ! 観測点の座標値[x 系での値]
+  real, intent(in) :: obs(size(obs_posi))  ! 観測点での観測値
+  character(1), intent(in) :: method  ! 影響球の形
+                              ! 'B' : Barnes (1964) によるガウシアン球
+                              ! 'C' : Cressman (1959) による有限球
+  real, intent(inout) :: inter_val(size(x))  ! 内挿された値
+  real, intent(in), optional :: rad  ! 影響球の半径[x 系での値]
+                                     ! デフォルトは各格子点からの最近の観測点を
+                                     ! 計算し, その最遠距離を設定.
+  real, intent(in), optional :: hx(size(x))  ! x 系におけるスケール因子.
+                                ! デフォルトはデカルト座標系として計算.
+  real, intent(in), optional :: hobs(size(obs_posi))  ! 観測点で定義された x 系におけるスケール因子.
+                                ! デフォルトはデカルト座標系として計算.
+  real, intent(in), optional :: lambda  ! 観測誤差標準偏差 / 背景誤差標準偏差
+                                       ! デフォルトではゼロ.
+!  real, intent(in), optional :: undef  ! 観測の欠損値[第一推定値には欠損がない]
   integer :: nx, i, j, k, nob, obs_i
   real :: lam
   real :: wei(size(x),size(obs_posi)), interp(size(obs_posi))
@@ -41,7 +41,7 @@ subroutine successive_modif_1d( x, fg, obs_posi, obs, method, inter_val,  &
   real :: geo_obs(size(obs_posi))
   real :: sphe_rad
 
-!-- undef бΤ, undef äƤ¬
+!-- undef 対応のため, undef が入っている観測点は
   nx=size(x)
   nob=size(obs_posi)
 
@@ -51,7 +51,7 @@ subroutine successive_modif_1d( x, fg, obs_posi, obs, method, inter_val,  &
      lam=0.0
   end if
 
-!-- ҤϤƤ, ŪľɸϤȤ.
+!-- スケール因子が入力されている場合, 幾何的直交座標系に落とす.
   if(present(hx).and.present(hobs))then
      do i=1,nx
         geo_fg(i)=hx(i)*x(i)
@@ -60,7 +60,7 @@ subroutine successive_modif_1d( x, fg, obs_posi, obs, method, inter_val,  &
         geo_obs(i)=hobs(i)*obs_posi(i)
      end do
   else
-     if(present(hx).or.present(hobs))then  ! ɤ餫ʤ, 顼Ȥʤ.
+     if(present(hx).or.present(hobs))then  ! どちらかしかない場合, エラーとなる.
         write(*,*) "#### ERROR ####"
         write(*,*) "hx 'and' hobs must be set. STOP"
         stop
@@ -74,8 +74,8 @@ subroutine successive_modif_1d( x, fg, obs_posi, obs, method, inter_val,  &
      end if
   end if
 
-!-- rad ꤵƤʤ, Ⱦ¤η׻
-!-- ƳʻǤκǶܴ¬ޤǤεΥ, ǱȤʤ.
+!-- rad が指定されていない場合の, 半径の計算
+!-- 各格子点での最近接観測点までの距離で, 最遠となる値.
   if(present(rad))then
      sphe_rad=rad
   else
@@ -86,29 +86,29 @@ subroutine successive_modif_1d( x, fg, obs_posi, obs, method, inter_val,  &
      call max_val_1d( fg2obs, obs_i, sphe_rad)
   end if
 
-!-- ͤѤ, ¬٤ƤͤޤԤ.
+!-- 第一推定値を用いて, 観測点すべてに第一推定値の線形内挿を行う.
   do k=1,nob
      call interpo_search_1d( x, obs_posi(k), fg_interp )
      call interpolation_1d( x(fg_interp:fg_interp+1), fg(fg_interp:fg_interp+1),  &
   &                         obs_posi(k), interp(k) )
   end do
 
-!-- ͳʻ, ¬ޤǤľΥ׻.
+!-- 各第一推定値格子点から, 全観測点までの直線距離を計算する.
   do k=1,nob
      do i=1,nx
         radius(i,k)=sqrt((geo_fg(i)-geo_obs(k))*(geo_fg(i)-geo_obs(k)))
      end do
   end do
 
-!-- Ťߴؿη׻
+!-- 重み関数の計算
   select case(method)
-  case('B')  ! Barnes ˡ
+  case('B')  ! Barnes 法
      do k=1,nob
         do i=1,nx
            wei(i,k)=exp(-(radius(i,k))/(sphe_rad))
         end do
      end do
-  case('C')  ! Cressman ˡ
+  case('C')  ! Cressman 法
      do k=1,nob
         do i=1,nx
            if(radius(i,j)<rad)then
@@ -124,7 +124,7 @@ subroutine successive_modif_1d( x, fg, obs_posi, obs, method, inter_val,  &
      stop
   end select
 
-!-- η׻
+!-- 修正項の計算
   do i=1,nx
      summ(i)=0.0
      summ_wei(i)=0.0
@@ -148,36 +148,36 @@ end subroutine successive_modif_1d
 subroutine successive_modif_2d( x, y, fg, obs_posix, obs_posiy, obs,  &
   &                             method, inter_val,  &
   &                             rad, hx, hy, hobsx, hobsy, lambda )!, undef )
-! 2 ǡˤĤ, ༡ˡˤޤԤ.
-! , ͤ¬ؤޤޤԤΤȤ.
-! ͤ򥼥Ȥ, ༡ޤԤ.
-! Ĥޤ, ¬ͤΤߤꤷޤԤ.
-!
+! 2 次元データについて, 逐次修正法による内挿を行う.
+! ここで, 第一推定値から観測点への内挿は線形内挿を行うものとする.
+! 第一推定値をゼロとすれば, 純粋な逐次内挿が行われる.
+! つまり, 観測値のみから推定した内挿が行える.
+!作成途中
   implicit none
-  real, intent(in) :: x(:)  ! Ǥ 1 ɸ[ľɸ]
-  real, intent(in) :: y(:)  ! Ǥ 2 ɸ[ľɸ]
-  real, intent(in) :: fg(size(x),size(y))  ! Ǥ
-  real, intent(in) :: obs_posix(:)  ! ¬κɸ[x ϤǤ]
-  real, intent(in) :: obs_posiy(:)  ! ¬κɸ[y ϤǤ]
-  real, intent(in) :: obs(size(obs_posix),size(obs_posiy))  ! ¬Ǥδ¬
-  character(1), intent(in) :: method  ! ƶη
-                              ! 'B' : Barnes (1964) ˤ륬
-                              ! 'C' : Cressman (1959) ˤͭµ
-  real, intent(inout) :: inter_val(size(x),size(y))  ! ޤ줿
-  real, intent(in), optional :: rad  ! ƶȾ[x ϤǤ]
-                                     ! ǥեȤϳƳʻκǶδ¬
-                                     ! ׻, κǱΥ.
-  real, intent(in), optional :: hx(size(x))  ! x Ϥˤ륹.
-                                ! ǥեȤϥǥȺɸϤȤƷ׻.
-  real, intent(in), optional :: hy(size(y))  ! y Ϥˤ륹.
-                                ! ǥեȤϥǥȺɸϤȤƷ׻.
-  real, intent(in), optional :: hobsx(size(obs_posix))  ! ¬줿 x Ϥˤ륹.
-                                ! ǥեȤϥǥȺɸϤȤƷ׻.
-  real, intent(in), optional :: hobsy(size(obs_posiy))  ! ¬줿 y Ϥˤ륹.
-                                ! ǥեȤϥǥȺɸϤȤƷ׻.
-  real, intent(in), optional :: lambda  ! ¬ɸк / طʸɸк
-                                       ! ǥեȤǤϥ.
-!  real, intent(in), optional :: undef  ! ¬η»[ͤˤϷ»ʤ]
+  real, intent(in) :: x(:)  ! 内挿点での第 1 座標値[直交座標系]
+  real, intent(in) :: y(:)  ! 内挿点での第 2 座標値[直交座標系]
+  real, intent(in) :: fg(size(x),size(y))  ! 内挿点での第一推定値
+  real, intent(in) :: obs_posix(:)  ! 観測点の座標値[x 系での値]
+  real, intent(in) :: obs_posiy(:)  ! 観測点の座標値[y 系での値]
+  real, intent(in) :: obs(size(obs_posix),size(obs_posiy))  ! 観測点での観測値
+  character(1), intent(in) :: method  ! 影響球の形
+                              ! 'B' : Barnes (1964) によるガウシアン球
+                              ! 'C' : Cressman (1959) による有限球
+  real, intent(inout) :: inter_val(size(x),size(y))  ! 内挿された値
+  real, intent(in), optional :: rad  ! 影響球の半径[x 系での値]
+                                     ! デフォルトは各格子点からの最近の観測点を
+                                     ! 計算し, その最遠距離を設定.
+  real, intent(in), optional :: hx(size(x))  ! x 系におけるスケール因子.
+                                ! デフォルトはデカルト座標系として計算.
+  real, intent(in), optional :: hy(size(y))  ! y 系におけるスケール因子.
+                                ! デフォルトはデカルト座標系として計算.
+  real, intent(in), optional :: hobsx(size(obs_posix))  ! 観測点で定義された x 系におけるスケール因子.
+                                ! デフォルトはデカルト座標系として計算.
+  real, intent(in), optional :: hobsy(size(obs_posiy))  ! 観測点で定義された y 系におけるスケール因子.
+                                ! デフォルトはデカルト座標系として計算.
+  real, intent(in), optional :: lambda  ! 観測誤差標準偏差 / 背景誤差標準偏差
+                                       ! デフォルトではゼロ.
+!  real, intent(in), optional :: undef  ! 観測の欠損値[第一推定値には欠損がない]
   integer :: nx, i, j, k, nob
   real :: lam
   real :: wei(size(x),size(obs_posi)), interp(size(obs_posi))
@@ -185,7 +185,7 @@ subroutine successive_modif_2d( x, y, fg, obs_posix, obs_posiy, obs,  &
   real :: geo_obs(size(obs_posi))
   real :: sphe_rad
 
-!-- undef бΤ, undef äƤ¬
+!-- undef 対応のため, undef が入っている観測点は
   nx=size(x)
   nob=size(obs_posi)
 
@@ -195,7 +195,7 @@ subroutine successive_modif_2d( x, y, fg, obs_posix, obs_posiy, obs,  &
      lam=0.0
   end if
 
-!-- ҤϤƤ, ŪľɸϤȤ.
+!-- スケール因子が入力されている場合, 幾何的直交座標系に落とす.
   if(present(hx).and.present(hobs))then
      do i=1,nx
         geo_fg(i)=hx(i)*x(i)
@@ -204,7 +204,7 @@ subroutine successive_modif_2d( x, y, fg, obs_posix, obs_posiy, obs,  &
         geo_obs(i)=hobs(i)*obs_posi(i)
      end do
   else
-     if(present(hx).or.present(hobs))then  ! ɤ餫ʤ, 顼Ȥʤ.
+     if(present(hx).or.present(hobs))then  ! どちらかしかない場合, エラーとなる.
         write(*,*) "#### ERROR ####"
         write(*,*) "hx 'and' hobs must be set. STOP"
         stop
@@ -218,8 +218,8 @@ subroutine successive_modif_2d( x, y, fg, obs_posix, obs_posiy, obs,  &
      end if
   end if
 
-!-- rad ꤵƤʤ, Ⱦ¤η׻
-!-- ƳʻǤκǶܴ¬ޤǤεΥ, ǱȤʤ.
+!-- rad が指定されていない場合の, 半径の計算
+!-- 各格子点での最近接観測点までの距離で, 最遠となる値.
   if(present(rad))then
      sphe_rad=rad
   else
@@ -230,29 +230,29 @@ subroutine successive_modif_2d( x, y, fg, obs_posix, obs_posiy, obs,  &
      call max_val_1d( fg2obs, obs_i, sphe_rad)
   end if
 
-!-- ͤѤ, ¬٤ƤͤޤԤ.
+!-- 第一推定値を用いて, 観測点すべてに第一推定値の線形内挿を行う.
   do k=1,nob
      call interpo_search_1d( x, obs_posi(k), fg_interp )
      call interpolation_1d( x(fg_interp:fg_interp+1), fg(fg_interp:fg_interp+1),  &
   &                         obs_posi(k), interp(k) )
   end do
 
-!-- ͳʻ, ¬ޤǤľΥ׻.
+!-- 各第一推定値格子点から, 全観測点までの直線距離を計算する.
   do k=1,nob
      do i=1,nx
         radius(i,k)=sqrt((geo_fg(i)-geo_obs(k))*(geo_fg(i)-geo_obs(k)))
      end do
   end do
 
-!-- Ťߴؿη׻
+!-- 重み関数の計算
   select case(method)
-  case('B')  ! Barnes ˡ
+  case('B')  ! Barnes 法
      do k=1,nob
         do i=1,nx
            wei(i,k)=exp(-(radius(i,k))/(sphe_rad))
         end do
      end do
-  case('C')  ! Cressman ˡ
+  case('C')  ! Cressman 法
      do k=1,nob
         do i=1,nx
            if(radius(i,j)<rad)then
@@ -268,7 +268,7 @@ subroutine successive_modif_2d( x, y, fg, obs_posix, obs_posiy, obs,  &
      stop
   end select
 
-!-- η׻
+!-- 修正項の計算
   do i=1,nx
      summ(i)=0.0
      summ_wei(i)=0.0
