@@ -202,6 +202,19 @@ end function
 !-----------------------------------
 !-----------------------------------
 
+double precision function c2d_convert( cval )
+! 文字型を倍精度実数型に変換する
+  implicit none
+  character(*), intent(in) :: cval  ! 変換する文字
+
+  read(cval,*) c2d_convert
+
+  return
+end function
+
+!-----------------------------------
+!-----------------------------------
+
 character(100) function i2c_convert( ival, forma )
 ! 実数型を文字型に変換する
   implicit none
