@@ -895,7 +895,7 @@ subroutine write_file_i1( file_name, nx, ny, rec_num, var, mode, funit )
   integer(1), intent(in) :: var(nx,ny)  ! 書き出すデータ
   character(*), optional, intent(in) :: mode  ! ファイルの書き出しオプション
   integer, intent(in), optional :: funit   ! ファイルユニット番号.
-                       ! デフォルト = 11.
+                       ! デフォルト = 12.
   integer :: i, j, unitn  ! 作業用配列
   character(10) :: cmode
   integer, parameter :: bnum=1
@@ -905,7 +905,7 @@ subroutine write_file_i1( file_name, nx, ny, rec_num, var, mode, funit )
   if(present(funit))then
      unitn=funit
   else
-     unitn=11
+     unitn=12
   end if
 
   if(present(mode))then
@@ -934,7 +934,7 @@ subroutine write_file_i2( file_name, nx, ny, rec_num, var, mode, funit )
   integer(2), intent(in) :: var(nx,ny)  ! 書き出すデータ
   character(*), optional, intent(in) :: mode  ! ファイルの書き出しオプション
   integer, intent(in), optional :: funit   ! ファイルユニット番号.
-                       ! デフォルト = 11.
+                       ! デフォルト = 12.
   integer :: i, j, unitn  ! 作業用配列
   character(10) :: cmode
   integer, parameter :: bnum=2
@@ -944,7 +944,7 @@ subroutine write_file_i2( file_name, nx, ny, rec_num, var, mode, funit )
   if(present(funit))then
      unitn=funit
   else
-     unitn=11
+     unitn=12
   end if
 
   if(present(mode))then
@@ -973,7 +973,7 @@ subroutine write_file_i4( file_name, nx, ny, rec_num, var, mode, funit )
   integer, intent(in) :: var(nx,ny)  ! 書き出すデータ
   character(*), optional, intent(in) :: mode  ! ファイルの書き出しオプション
   integer, intent(in), optional :: funit   ! ファイルユニット番号.
-                       ! デフォルト = 11.
+                       ! デフォルト = 12.
   integer :: i, j, unitn  ! 作業用配列
   character(10) :: cmode
   integer, parameter :: bnum=4
@@ -983,7 +983,7 @@ subroutine write_file_i4( file_name, nx, ny, rec_num, var, mode, funit )
   if(present(funit))then
      unitn=funit
   else
-     unitn=11
+     unitn=12
   end if
 
   if(present(mode))then
@@ -1012,7 +1012,7 @@ subroutine write_file_f4( file_name, nx, ny, rec_num, var, mode, funit )
   real, intent(in) :: var(nx,ny)  ! 書き出すデータ
   character(*), optional, intent(in) :: mode  ! ファイルの書き出しオプション
   integer, intent(in), optional :: funit   ! ファイルユニット番号.
-                       ! デフォルト = 11.
+                       ! デフォルト = 12.
   integer :: i, j, unitn  ! 作業用配列
   character(10) :: cmode
   integer, parameter :: bnum=4
@@ -1022,7 +1022,7 @@ subroutine write_file_f4( file_name, nx, ny, rec_num, var, mode, funit )
   if(present(funit))then
      unitn=funit
   else
-     unitn=11
+     unitn=12
   end if
 
   if(present(mode))then
@@ -1051,7 +1051,7 @@ subroutine write_file_d8( file_name, nx, ny, rec_num, var, mode, funit )
   double precision, intent(in) :: var(nx,ny)  ! 書き出すデータ
   character(*), optional, intent(in) :: mode  ! ファイルの書き出しオプション
   integer, intent(in), optional :: funit   ! ファイルユニット番号.
-                       ! デフォルト = 11.
+                       ! デフォルト = 12.
   integer :: i, j, unitn  ! 作業用配列
   character(10) :: cmode
   integer, parameter :: bnum=8
@@ -1061,7 +1061,7 @@ subroutine write_file_d8( file_name, nx, ny, rec_num, var, mode, funit )
   if(present(funit))then
      unitn=funit
   else
-     unitn=11
+     unitn=12
   end if
 
   if(present(mode))then
@@ -1091,7 +1091,7 @@ subroutine write_file_3di1( file_name, nx, ny, nz, rec_num, var, mode, funit )
   integer(1), intent(in) :: var(nx,ny,nz)  ! 読み出すデータ
   character(*), optional, intent(in) :: mode  ! ファイルの書き出しオプション
   integer, intent(in), optional :: funit   ! ファイルユニット番号.
-                       ! デフォルト = 11.
+                       ! デフォルト = 12.
   integer :: i, j, k, unitn  ! 作業用配列
   character(10) :: cmode
   integer, parameter :: bnum=1
@@ -1101,7 +1101,7 @@ subroutine write_file_3di1( file_name, nx, ny, nz, rec_num, var, mode, funit )
   if(present(funit))then
      unitn=funit
   else
-     unitn=11
+     unitn=12
   end if
 
   if(present(mode))then
@@ -1133,7 +1133,7 @@ subroutine write_file_3di2( file_name, nx, ny, nz, rec_num, var, mode, funit )
   integer(2), intent(in) :: var(nx,ny,nz)  ! 読み出すデータ
   character(*), optional, intent(in) :: mode  ! ファイルの書き出しオプション
   integer, intent(in), optional :: funit   ! ファイルユニット番号.
-                       ! デフォルト = 11.
+                       ! デフォルト = 12.
   integer :: i, j, k, unitn  ! 作業用配列
   character(10) :: cmode
   integer, parameter :: bnum=2
@@ -1143,7 +1143,7 @@ subroutine write_file_3di2( file_name, nx, ny, nz, rec_num, var, mode, funit )
   if(present(funit))then
      unitn=funit
   else
-     unitn=11
+     unitn=12
   end if
 
   if(present(mode))then
@@ -1175,7 +1175,7 @@ subroutine write_file_3di4( file_name, nx, ny, nz, rec_num, var, mode, funit )
   integer, intent(in) :: var(nx,ny,nz)  ! 読み出すデータ
   character(*), optional, intent(in) :: mode  ! ファイルの書き出しオプション
   integer, intent(in), optional :: funit   ! ファイルユニット番号.
-                       ! デフォルト = 11.
+                       ! デフォルト = 12.
   integer :: i, j, k, unitn  ! 作業用配列
   character(10) :: cmode
   integer, parameter :: bnum=4
@@ -1185,7 +1185,7 @@ subroutine write_file_3di4( file_name, nx, ny, nz, rec_num, var, mode, funit )
   if(present(funit))then
      unitn=funit
   else
-     unitn=11
+     unitn=12
   end if
 
   if(present(mode))then
@@ -1217,7 +1217,7 @@ subroutine write_file_3df4( file_name, nx, ny, nz, rec_num, var, mode, funit )
   real, intent(in) :: var(nx,ny,nz)  ! 読み出すデータ
   character(*), optional, intent(in) :: mode  ! ファイルの書き出しオプション
   integer, intent(in), optional :: funit   ! ファイルユニット番号.
-                       ! デフォルト = 11.
+                       ! デフォルト = 12.
   integer :: i, j, k, unitn  ! 作業用配列
   character(10) :: cmode
   integer, parameter :: bnum=4
@@ -1227,7 +1227,7 @@ subroutine write_file_3df4( file_name, nx, ny, nz, rec_num, var, mode, funit )
   if(present(funit))then
      unitn=funit
   else
-     unitn=11
+     unitn=12
   end if
 
   if(present(mode))then
@@ -1259,7 +1259,7 @@ subroutine write_file_3dd8( file_name, nx, ny, nz, rec_num, var, mode, funit )
   double precision, intent(in) :: var(nx,ny,nz)  ! 読み出すデータ
   character(*), optional, intent(in) :: mode  ! ファイルの書き出しオプション
   integer, intent(in), optional :: funit   ! ファイルユニット番号.
-                       ! デフォルト = 11.
+                       ! デフォルト = 12.
   integer :: i, j, k, unitn  ! 作業用配列
   character(10) :: cmode
   integer, parameter :: bnum=8
@@ -1269,7 +1269,7 @@ subroutine write_file_3dd8( file_name, nx, ny, nz, rec_num, var, mode, funit )
   if(present(funit))then
      unitn=funit
   else
-     unitn=11
+     unitn=12
   end if
 
   if(present(mode))then
@@ -2528,6 +2528,56 @@ subroutine read_mgdsst( fname, sst, funit )
 
 end subroutine
 
+!-----------------------------------
+!-----------------------------------
+
+subroutine read_himsst( fname, sst, funit )
+! himsst データを読み込むためのルーチン
+! 読み込み用データは 800 x 800 で固定.
+! これは, himsst のフォーマットからくるものである.
+  implicit none
+  integer, parameter :: nx=800  ! 経度方向の格子点数
+  integer, parameter :: ny=600  ! 緯度方向の格子点数
+  character(*), intent(in) :: fname  ! 読み込む himsst ルーチン
+  real, intent(inout), dimension(nx,ny) :: sst  ! 読み込んだ SST データ [K].
+                              ! ただし, 999.0 が未定義, 888.0 が海氷.
+  integer, intent(in), optional :: funit   ! ファイルユニット番号.
+                       ! デフォルト = 11.
+  character(3), dimension(nx,ny) :: sstc
+  character(10) :: formatt
+  integer :: j, k, unitn
+
+  if(present(funit))then
+     unitn=funit
+  else
+     unitn=11
+  end if
+
+  formatt='(800a3)'
+
+  call read_file_text( trim(fname), nx, ny, sstc, skip=1, forma=trim(formatt),  &
+  &                    funit=unitn )
+!  open(unit=12,file=trim(dat_list(i)),status='old')
+!     read(12,*) sstc(1,1)
+  do k=1,ny
+!     read(12,formatt) (sstc(j,k),j=1,nx)
+     do j=1,nx
+        if(sstc(j,k)=='888')then
+           sst(j,ny-k+1)=263.15
+        else if(sstc(j,k)=='999')then
+           sst(j,ny-k+1)=999.0
+        else
+           read(sstc(j,k),*) sst(j,ny-k+1)
+           sst(j,ny-k+1)=sst(j,ny-k+1)/10.0+273.15
+!           write(*,*) j,k,sstc(j,k),sst(j,k)
+        end if
+!        tmp(j,ny-k+1)=sst(j,k)
+!        sst(j,k)=tmp(j,k)
+     end do
+  end do
+
+end subroutine
+
 !-----------------------------------
 !  private routine
 !-----------------------------------
