@@ -2,7 +2,7 @@
 ! Copyright (C) 2009-2015 GFD Dennou Club. All rights reserved.
 !---------------------------------------------------------------
 
-module Geometry  ! ؤ˴ؤ롼
+module Geometry  ! 幾何学に関するルーチン
 
   public :: rt_2_xy,  &
   &         xy_2_rt
@@ -20,17 +20,17 @@ module Geometry  ! ؤ˴ؤ롼
 contains
 
 subroutine rt_2_xy_r( r, t, x, y )
-! ʿ̶˺ɸʿ̥ǥȺɸؤѴ
+! 平面極座標から平面デカルト座標への変換
 !
-! ξϺɸθ r ǼưŪ˻ꤵƤΤ,
-! ꤹɬפʤ.
-! դ֤ x, y ͤ, r=0 Ȥ
-! ǥȺɸϤȤ֤뤳Ȥդ.
+! この場合は座標の原点が r で自動的に指定されているので,
+! 原点を指定する引数は必要ない.
+! 逆に返される x, y の値は, r=0 を原点とした
+! デカルト座標系として返されることに注意する.
   implicit none
-  real, intent(in) :: r  ! 濴εΥ
-  real, intent(in) :: t  ! x γ [rad]
-  real, intent(inout) :: x  ! x ɸ
-  real, intent(inout) :: y  ! y ɸ
+  real, intent(in) :: r  ! 中心からの距離
+  real, intent(in) :: t  ! x 軸からの角度 [rad]
+  real, intent(inout) :: x  ! x 座標
+  real, intent(inout) :: y  ! y 座標
 
   x=r*cos(t)
   y=r*sin(t)
@@ -39,17 +39,17 @@ end subroutine
 
 
 subroutine rt_2_xy_d( r, t, x, y )
-! ʿ̶˺ɸʿ̥ǥȺɸؤѴ
+! 平面極座標から平面デカルト座標への変換
 !
-! ξϺɸθ r ǼưŪ˻ꤵƤΤ,
-! ꤹɬפʤ.
-! դ֤ x, y ͤ, r=0 Ȥ
-! ǥȺɸϤȤ֤뤳Ȥդ.
+! この場合は座標の原点が r で自動的に指定されているので,
+! 原点を指定する引数は必要ない.
+! 逆に返される x, y の値は, r=0 を原点とした
+! デカルト座標系として返されることに注意する.
   implicit none
-  double precision, intent(in) :: r  ! 濴εΥ
-  double precision, intent(in) :: t  ! x γ [rad]
-  double precision, intent(inout) :: x  ! x ɸ
-  double precision, intent(inout) :: y  ! y ɸ
+  double precision, intent(in) :: r  ! 中心からの距離
+  double precision, intent(in) :: t  ! x 軸からの角度 [rad]
+  double precision, intent(inout) :: x  ! x 座標
+  double precision, intent(inout) :: y  ! y 座標
 
   x=r*dcos(t)
   y=r*dsin(t)
@@ -58,20 +58,20 @@ end subroutine
 
 
 subroutine xy_2_rt_r( x, y, xc, yc, r, t )
-! ʿ̥ǥȺɸʿ̶˺ɸؤѴ
+! 平面デカルト座標から平面極座標への変換
 !
-! ξϺɸθ r ǼưŪ˻ꤵƤΤ,
-! ꤹɬפʤ.
-! դ֤ x, y ͤ, r=0 Ȥ
-! ǥȺɸϤȤ֤뤳Ȥդ.
+! この場合は座標の原点が r で自動的に指定されているので,
+! 原点を指定する引数は必要ない.
+! 逆に返される x, y の値は, r=0 を原点とした
+! デカルト座標系として返されることに注意する.
   use Math_Const
   implicit none
-  real, intent(in) :: x  ! x ɸ
-  real, intent(in) :: y  ! y ɸ
-  real, intent(in) :: xc ! x ɸ濴
-  real, intent(in) :: yc ! y ɸ濴
-  real, intent(inout) :: r  ! 濴εΥ
-  real, intent(inout) :: t  ! x γ [rad]
+  real, intent(in) :: x  ! x 座標
+  real, intent(in) :: y  ! y 座標
+  real, intent(in) :: xc ! x 座標中心点
+  real, intent(in) :: yc ! y 座標中心点
+  real, intent(inout) :: r  ! 中心からの距離
+  real, intent(inout) :: t  ! x 軸からの角度 [rad]
   real :: rx, ry
 
   rx=x-xc
@@ -109,20 +109,20 @@ end subroutine
 
 
 subroutine xy_2_rt_d( x, y, xc, yc, r, t )
-! ʿ̥ǥȺɸʿ̶˺ɸؤѴ
+! 平面デカルト座標から平面極座標への変換
 !
-! ξϺɸθ r ǼưŪ˻ꤵƤΤ,
-! ꤹɬפʤ.
-! դ֤ x, y ͤ, r=0 Ȥ
-! ǥȺɸϤȤ֤뤳Ȥդ.
+! この場合は座標の原点が r で自動的に指定されているので,
+! 原点を指定する引数は必要ない.
+! 逆に返される x, y の値は, r=0 を原点とした
+! デカルト座標系として返されることに注意する.
   use Math_Const
   implicit none
-  double precision, intent(in) :: x  ! x ɸ
-  double precision, intent(in) :: y  ! y ɸ
-  double precision, intent(in) :: xc ! x ɸ濴
-  double precision, intent(in) :: yc ! y ɸ濴
-  double precision, intent(inout) :: r  ! 濴εΥ
-  double precision, intent(inout) :: t  ! x γ [rad]
+  double precision, intent(in) :: x  ! x 座標
+  double precision, intent(in) :: y  ! y 座標
+  double precision, intent(in) :: xc ! x 座標中心点
+  double precision, intent(in) :: yc ! y 座標中心点
+  double precision, intent(inout) :: r  ! 中心からの距離
+  double precision, intent(inout) :: t  ! x 軸からの角度 [rad]
   double precision :: rx, ry
 
   rx=x-xc
@@ -160,17 +160,17 @@ end subroutine
 
 
 subroutine product_circle( xp, yp, rad, num, xd, yd )
-! ǥ xp, yp Ⱦ rad αߤ, ͤ
-! ˺ɸƱ̳ num ĤǤ˳Ǽ.
-! xd, yd αߤΥǥȺɸǤ.
+! デカルト点 xp, yp から半径 rad の円を描き, その値を
+! 極座標の同位角方向に num 個の配列要素に格納する.
+! xd, yd がその円のデカルト座標での値.
   use math_const
   implicit none
-  real, intent(in) :: xp  ! ߤ濴 x ɸ
-  real, intent(in) :: yp  ! ߤ濴 y ɸ
-  real, intent(in) :: rad  ! ߤȾ
-  integer, intent(in) :: num  ! ǿ
-  real, intent(inout) :: xd(num)  ! ߤ x ɸǡ
-  real, intent(inout) :: yd(num)  ! ߤ y ɸǡ
+  real, intent(in) :: xp  ! 円の中心 x 座標
+  real, intent(in) :: yp  ! 円の中心 y 座標
+  real, intent(in) :: rad  ! 円の半径
+  integer, intent(in) :: num  ! 配列要素数
+  real, intent(inout) :: xd(num)  ! 円の x 座標データ
+  real, intent(inout) :: yd(num)  ! 円の y 座標データ
   integer :: i
 
   do i=1,num
@@ -181,22 +181,22 @@ subroutine product_circle( xp, yp, rad, num, xd, yd )
 end subroutine
 
 !subroutine xy_2_rt( x, y, r, t )
-! ʿ̥ǥȺɸʿ̶˺ɸؤѴ
+! 平面デカルト座標から平面極座標への変換
 !
-! x=0, y=0  r=0 θȤʤä֤뤳Ȥ.
-! ʿ̶˺ɸǤθȤʤ.
+! x=0, y=0 の点が r=0 の原点となって返されることに注意.
+! この点が平面極座標での原点となる.
 !  implicit none
-!  real, intent(in) :: x  ! x ɸ
-!  real, intent(in) :: y  ! y ɸ
-!  real, intent(inout) :: r  ! 濴εΥ
-!  real, intent(inout) :: t  ! x γ [rad]
+!  real, intent(in) :: x  ! x 座標
+!  real, intent(in) :: y  ! y 座標
+!  real, intent(inout) :: r  ! 中心からの距離
+!  real, intent(inout) :: t  ! x 軸からの角度 [rad]
 
-!  r=sqrt(x**2+y**2)  ! Ϥɤξݸ¤ǤƱ׻ɾǤ.
+!  r=sqrt(x**2+y**2)  ! これはどの象限でも同じ計算式で評価できる.
 
 !  if(x=0.0.and.y=0.0)then
 !     t=0.0
 !  else
-!     if(x*y>0.0)then  ! x*y>0 ʤ,  1, 3 ݸΰɽ.
+!     if(x*y>0.0)then  ! x*y>0 なら, 第 1, 3 象限領域を表す.
 !        t=
 !     else
 !     end if
