@@ -262,7 +262,7 @@ subroutine invert_mat_f( ax, xx )
   d(1:nx,1:nx)=ax(1:nx,1:nx)  ! ダミー変数へ代入
 
   do i=1,nx
-     call gausssf( d, c(:,i), xx(:,i) )  ! 配列第 2 成分が列を表すので, この順番で OK.
+     call gausssf( d, c(i,:), xx(i,:) )  ! 配列第 2 成分が列を表すので, この順番で OK.
   end do
 
 end subroutine invert_mat_f
@@ -293,7 +293,7 @@ subroutine invert_mat_d( ax, xx )
   d(1:nx,1:nx)=ax(1:nx,1:nx)  ! ダミー変数へ代入
 
   do i=1,nx
-     call gausssd( d, c(:,i), xx(:,i) )  ! 配列第 2 成分が列を表すので, この順番で OK.
+     call gausssd( d, c(i,:), xx(i,:) )  ! 配列第 2 成分が列を表すので, この順番で OK.
   end do
 
 end subroutine invert_mat_d
@@ -324,7 +324,7 @@ subroutine fp_invert_mat_f( ax, xx )
   d(1:nx,1:nx)=ax(1:nx,1:nx)  ! ダミー変数へ代入
 
   do i=1,nx
-     call fp_gaussf( d, c(:,i), xx(:,i) )  ! 配列第 2 成分が列を表すので, この順番で OK.
+     call fp_gaussf( d, c(i,:), xx(i,:) )  ! 配列第 2 成分が列を表すので, この順番で OK.
   end do
 
 end subroutine fp_invert_mat_f
@@ -355,7 +355,7 @@ subroutine fp_invert_mat_d( ax, xx )
   d(1:nx,1:nx)=ax(1:nx,1:nx)  ! ダミー変数へ代入
 
   do i=1,nx
-     call fp_gaussd( d, c(:,i), xx(:,i) )  ! 配列第 2 成分が列を表すので, この順番で OK.
+     call fp_gaussd( d, c(i,:), xx(i,:) )  ! 配列第 2 成分が列を表すので, この順番で OK.
   end do
 
 end subroutine fp_invert_mat_d
